@@ -1,6 +1,6 @@
 from django.contrib.auth.models import User
-from tendenci.core.registry import site
-from tendenci.core.registry.base import LogRegistry, lazy_reverse
+from tendenci.apps.registry.sites import site
+from tendenci.apps.registry.base import LogRegistry
 
 class AccountRegistry(LogRegistry):
     """User related logs
@@ -15,4 +15,3 @@ class AccountRegistry(LogRegistry):
     }
 
 site.register(User, AccountRegistry)
-
