@@ -1,7 +1,7 @@
-from tendenci.core.perms.managers import TendenciBaseManager
+from tendenci.apps.perms.managers import TendenciBaseManager
 
 class BoxManager(TendenciBaseManager):
     """
     Model Manager
     """
-    pass
\ No newline at end of file
+    pass
