@@ -1,5 +1,5 @@
-from tendenci.core.registry import site
-from tendenci.core.registry.base import LogRegistry, lazy_reverse
+from tendenci.apps.registry.sites import site
+from tendenci.apps.registry.base import LogRegistry
 from tendenci.apps.contacts.models import Contact
 
 class ContactRegistry(LogRegistry):
@@ -12,4 +12,3 @@ class ContactRegistry(LogRegistry):
     }
 
 site.register(Contact, ContactRegistry)
-
