@@ -1,33 +1,35 @@
 from datetime import datetime
 from django.db import models
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.contenttypes import generic
+from django.contrib.contenttypes.fields import GenericRelation
 from django.db.models import Q
 from django.contrib.contenttypes.models import ContentType
 
-from tendenci.core.perms.models import TendenciBaseModel
-from tendenci.core.perms.object_perms import ObjectPermission
+from tendenci.apps.perms.models import TendenciBaseModel
+from tendenci.apps.perms.object_perms import ObjectPermission
 from tendenci.apps.invoices.models import Invoice
 from tendenci.apps.discounts.managers import DiscountManager
 
 class Discount(TendenciBaseModel):
-    class Meta:
-        permissions = (("view_discount",_("Can view discount")),)
-
     discount_code = models.CharField(max_length=100, unique=True, help_text=_('Discount codes must be unique.'))
     start_dt = models.DateTimeField(_('Start Date/Time'))
     end_dt = models.DateTimeField(_('Start Date/Time'))
     apps = models.ManyToManyField(ContentType, verbose_name=_('Applications'), help_text=_('Select the applications that can use this discount.'))
-    never_expires = models.BooleanField(_('Never Expires'), help_text=_('Check this box to make the discount code never expire.'))
+    never_expires = models.BooleanField(_('Never Expires'), help_text=_('Check this box to make the discount code never expire.'), default=False)
     value = models.DecimalField(_('Discount Value'), max_digits=10, decimal_places=2, help_text=_('Enter discount value as a positive number.'))
-    cap = models.IntegerField(_('Maximum Uses'), help_text=_('Enter 0 for unlimited discount code uses.'))
+    cap = models.IntegerField(_('Maximum Uses'), help_text=_('Enter 0 for unlimited discount code uses.'), default=0)
 
-    perms = generic.GenericRelation(ObjectPermission,
+    perms = GenericRelation(ObjectPermission,
                                           object_id_field="object_id",
                                           content_type_field="content_type")
 
     objects = DiscountManager()
 
+    class Meta:
+#         permissions = (("view_discount",_("Can view discount")),)
+        app_label = 'discounts'
+
     def num_of_uses(self):
         return self.discountuse_set.count()
 
@@ -52,12 +54,11 @@ class Discount(TendenciBaseModel):
             return False
         return True
 
-    def __unicode__(self):
+    def __str__(self):
         return self.discount_code
 
-    @models.permalink
     def get_absolute_url(self):
-        return('discount.detail', [self.pk])
+        return reverse('discount.detail', args=[self.pk])
 
     @staticmethod
     def has_valid_discount(**kwargs):
@@ -70,10 +71,20 @@ class Discount(TendenciBaseModel):
                             ).filter(apps__model=model).exists()
         return discount_exists
 
+    def delete(self, *args, **kwargs):
+        # Append id to the discount_code to avoid IntegrityError when the discount_code
+        # is used again later
+        self.discount_code = '{0}-{1}'.format(self.discount_code, self.id)
+        super(Discount, self).delete(*args, **kwargs)
+
+
 class DiscountUse(models.Model):
-    invoice = models.ForeignKey(Invoice)
-    discount = models.ForeignKey(Discount)
+    invoice = models.ForeignKey(Invoice, on_delete=models.CASCADE)
+    discount = models.ForeignKey(Discount, on_delete=models.CASCADE)
     create_dt = models.DateTimeField(auto_now_add=True)
 
-    def __unicode__(self):
+    class Meta:
+        app_label = 'discounts'
+
+    def __str__(self):
         return "%s:%s" % (self.invoice, self.discount)
