@@ -1,26 +1,25 @@
+from builtins import str
+
 from django.utils.translation import ugettext_lazy as _
-from django.utils import simplejson as json
+import json
 from django.views.decorators.csrf import csrf_exempt
 from django.contrib.auth.decorators import login_required
 from django.shortcuts import get_object_or_404, redirect
-from django.template import RequestContext
 from django.contrib import messages
-from django.http import HttpResponse, HttpResponseRedirect
-from django.conf import settings
+from django.http import HttpResponse
 
-from tendenci.core.base.http import Http403
-from tendenci.core.perms.decorators import is_enabled
-from tendenci.core.perms.utils import has_perm, update_perms_and_save, get_query_filters
-from tendenci.core.event_logs.models import EventLog
-from tendenci.core.theme.shortcuts import themed_response as render_to_response
-from tendenci.core.exports.utils import run_export_task
+from tendenci.apps.base.http import Http403
+from tendenci.apps.perms.decorators import is_enabled
+from tendenci.apps.perms.utils import has_perm, update_perms_and_save, get_query_filters
+from tendenci.apps.event_logs.models import EventLog
+from tendenci.apps.theme.shortcuts import themed_response as render_to_resp
+from tendenci.apps.exports.utils import run_export_task
 
-from tendenci.addons.events.models import Registration
-from tendenci.addons.memberships.models import MembershipSet
+from tendenci.apps.events.models import Registration
+from tendenci.apps.memberships.models import MembershipSet
 from tendenci.apps.discounts.models import Discount, DiscountUse
 from tendenci.apps.discounts.forms import DiscountForm, DiscountCodeForm, DiscountHandlingForm
-from tendenci.core.site_settings.utils import get_setting
-from tendenci.apps.redirects.models import Redirect
+from tendenci.apps.base.utils import LazyEncoder
 
 
 @is_enabled('discounts')
@@ -37,16 +36,15 @@ def search(request, template_name="discounts/search.html"):
 
     EventLog.objects.log()
 
-    return render_to_response(
-        template_name,
-        {'discounts':discounts},
-        context_instance=RequestContext(request)
+    return render_to_resp(
+        request=request, template_name=template_name,
+        context={'discounts':discounts}
     )
 
 
 @is_enabled('discounts')
 @login_required
-def detail(request, id, template_name="discounts/detail.html"):
+def detail(request, id, template_name="discounts/view.html"):
     discount = get_object_or_404(Discount, id=id)
 
     if not has_perm(request.user, 'discounts.view_discount', discount):
@@ -65,12 +63,11 @@ def detail(request, id, template_name="discounts/detail.html"):
 
     EventLog.objects.log(instance=discount)
 
-    return render_to_response(
-        template_name,
-        {'discount':discount,
+    return render_to_resp(
+        request=request, template_name=template_name,
+        context={'discount':discount,
          'registrant_list':registrant_list,
-         'membership_list':membership_list},
-        context_instance=RequestContext(request)
+         'membership_list':membership_list}
     )
 
 
@@ -91,10 +88,8 @@ def add(request, form_class=DiscountForm, template_name="discounts/add.html"):
     else:
         form = form_class(user=request.user)
 
-    return render_to_response(
-        template_name,
-        {'form':form},
-        context_instance=RequestContext(request),
+    return render_to_resp(request=request, template_name=template_name,
+        context={'form':form}
     )
 
 
@@ -116,13 +111,11 @@ def edit(request, id, form_class=DiscountForm, template_name="discounts/edit.htm
     else:
         form = form_class(instance=discount, user=request.user)
 
-    return render_to_response(
-        template_name,
-        {
+    return render_to_resp(request=request, template_name=template_name,
+        context={
             'form': form,
             'discount': discount,
-        },
-        context_instance=RequestContext(request),
+        }
     )
 
 
@@ -140,8 +133,8 @@ def delete(request, id, template_name="discounts/delete.html"):
 
         return redirect('discounts')
 
-    return render_to_response(template_name, {'discount': discount},
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'discount': discount})
 
 
 @is_enabled('discounts')
@@ -153,20 +146,20 @@ def discounted_price(request, form_class=DiscountCodeForm):
             return HttpResponse(json.dumps(
                 {
                     "error": False,
-                    "price": unicode(form.new_price()[0]),
-                    "discount": unicode(form.new_price()[1]),
-                    "message": _("Your discount of $ %(p)s has been added." % {'p': unicode(form.new_price()[1])}),
-                }), mimetype="text/plain")
+                    "price": str(form.new_price()[0]),
+                    "discount": str(form.new_price()[1]),
+                    "message": _("Your discount of $ %(p)s has been added." % {'p': str(form.new_price()[1])}),
+                }, cls=LazyEncoder), content_type="text/plain")
         return HttpResponse(json.dumps(
             {
                 "error": True,
                 "message": _("This is not a valid discount code."),
-            }), mimetype="text/plain")
+            }, cls=LazyEncoder), content_type="text/plain")
     else:
         form = form_class()
     return HttpResponse(
         "<form action='' method='post'>" + form.as_p() + "<input type='submit' value='check'> </form>",
-        mimetype="text/html")
+        content_type="text/html")
 
 
 @is_enabled('discounts')
@@ -180,7 +173,7 @@ def discounted_prices(request, check=False, form_class=DiscountHandlingForm):
                 {
                     "error": False,
                     "message": _("A discount of $%(d)s has been added." % { 'd': form.discount.value}),
-                }), mimetype="text/plain")
+                }, cls=LazyEncoder), content_type="text/plain")
 
             price_list, discount_total, discount_list, msg = form.get_discounted_prices()
             total = sum(price_list)
@@ -192,24 +185,24 @@ def discounted_prices(request, check=False, form_class=DiscountHandlingForm):
             return HttpResponse(json.dumps(
                 {
                     "error": False,
-                    "prices": unicode(new_prices),
-                    "discount_total": unicode(discount_total),
-                    "total": unicode(total),
+                    "prices": str(new_prices),
+                    "discount_total": str(discount_total),
+                    "total": str(total),
                     "message": _("%(m)sYour discount of $%(dt)s %(dd)s has been added." % {
-                        'm' : unicode(msg),
-                        'dt' : unicode(discount_total),
+                        'm' : str(msg),
+                        'dt' : str(discount_total),
                         'dd' : discount_detail }),
-                }), mimetype="text/plain")
+                }, cls=LazyEncoder), content_type="text/plain")
         return HttpResponse(json.dumps(
             {
                 "error": True,
                 "message": _("This is not a valid discount code."),
-            }), mimetype="text/plain")
+            }, cls=LazyEncoder), content_type="text/plain")
     else:
         form = form_class()
     return HttpResponse(
         "<form action='' method='post'>" + form.as_p() + "<input type='submit' value='check'> </form>",
-        mimetype="text/html")
+        content_type="text/html")
 
 @is_enabled('discounts')
 @login_required
@@ -232,5 +225,5 @@ def export(request, template_name="discounts/export.html"):
         EventLog.objects.log()
         return redirect('export.status', export_id)
 
-    return render_to_response(template_name, {
-    }, context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name, context={
+    })
