@@ -1,26 +1,25 @@
-
+from builtins import str
 from csv import writer
 from datetime import datetime
-from mimetypes import guess_type
 
-
-from django.conf import settings
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import url
 from django.contrib import admin
-from django.contrib.admin.util import unquote
+from django.contrib.admin.utils import unquote
 from django.core.files.base import ContentFile
 from django.core.files.storage import default_storage
-from django.core.urlresolvers import reverse
-from django.http import HttpResponse, Http404
+from django.urls import reverse
+from django.http import HttpResponse, Http404, HttpResponseRedirect
 from django.shortcuts import get_object_or_404
 from django.template.defaultfilters import slugify
 from django.utils.translation import ugettext_lazy as _
+from django.utils.safestring import mark_safe
 
-from tendenci.core.perms.admin import TendenciBaseModelAdmin
-from tendenci.core.site_settings.utils import get_setting
-
-from tendenci.apps.forms_builder.forms.models import Form, Field, FormEntry, FieldEntry, Pricing
+from tendenci.apps.perms.admin import TendenciBaseModelAdmin
+from tendenci.apps.site_settings.utils import get_setting
+from tendenci.apps.theme.templatetags.static import static
+from tendenci.apps.forms_builder.forms.models import Form, Field, FieldEntry, Pricing, FormEntry
 from tendenci.apps.forms_builder.forms.forms import FormAdminForm, FormForField, PricingForm
+from tendenci.apps.forms_builder.forms.utils import form_entries_to_csv_writer
 
 import os
 import mimetypes
@@ -46,6 +45,8 @@ class PricingAdmin(admin.StackedInline):
 class FieldAdminForm(FormForField):
     class Meta:
         model = Field
+        # django 1.8 requires either 'fields' or 'exclude' for ModelForm
+        exclude = ()
 
 
 class FieldAdmin(admin.TabularInline):
@@ -58,14 +59,15 @@ class FieldAdmin(admin.TabularInline):
 class FormAdmin(TendenciBaseModelAdmin):
 
     inlines = (PricingAdmin, FieldAdmin,)
-    list_display = ("title", "id", "intro", "email_from", "email_copies",
-        "admin_link_export", 'export_all_link', "admin_link_view")
+    list_display = ("title", "intro", "email_from", "email_copies",
+        "admin_link_export", 'export_all_link', "admin_link_view", 'group',)
     list_display_links = ("title",)
 #    list_filter = ("status",)
     search_fields = ("title", "intro", "response", "email_from",
         "email_copies")
 #    radio_fields = {"status": admin.HORIZONTAL}
     prepopulated_fields = {'slug': ['title']}
+    list_filter = ('group', )
 
     if not get_setting('module', 'recurring_payments', 'enabled'):
         payment_fields = ("custom_payment", "payment_methods")
@@ -76,7 +78,7 @@ class FormAdmin(TendenciBaseModelAdmin):
     section_name_fields = ("intro_name", "fields_name", "pricing_name")
 
     fieldsets = (
-        (None, {"fields": ("title", "slug", "intro", "response", "completion_url", "template")}),
+        (None, {"fields": ("title", "slug", "intro", "response", "completion_url", 'group', "template")}),
         (_("Email"), {"fields": ('subject_template', "email_from", "email_copies", "send_email", "email_text")}),
         (_('Permissions'), {'fields': ('allow_anonymous_view',)}),
         (_('Advanced Permissions'), {'classes': ('collapse',), 'fields': (
@@ -99,39 +101,38 @@ class FormAdmin(TendenciBaseModelAdmin):
     class Media:
         js = (
             '//ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js',
-            '//ajax.googleapis.com/ajax/libs/jqueryui/1.11.0/jquery-ui.min.js',
-            '%sjs/global/tinymce.event_handlers.js' % settings.STATIC_URL,
-            '%sjs/admin/form-fields-inline-ordering.js' % settings.STATIC_URL,
-            '%sjs/admin/form-field-dynamic-hiding.js' % settings.STATIC_URL,
-            '%sjs/admin/form-position.js' % settings.STATIC_URL,
-            '%sjs/admin/tax_fields.js' % settings.STATIC_URL,
+            '//ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js',
+            static('js/global/tinymce.event_handlers.js'),
+            static('js/admin/form-fields-inline-ordering.js'),
+            static('js/admin/form-field-dynamic-hiding.js'),
+            static('js/admin/form-position.js'),
+            static('js/admin/tax_fields.js'),
         )
-        css = {'all': ['%scss/admin/dynamic-inlines-with-sort.css' % settings.STATIC_URL], }
+        css = {'all': [static('css/admin/dynamic-inlines-with-sort.css')], }
 
+    @mark_safe
     def export_all_link(self, obj):
         link = '-----'
         if obj.has_files():
             link = '<a href="%s" title="Export all">Export entries (including uploaded files)</a>' % reverse('form_entries_export_full', args=[obj.pk])
         return link
-    export_all_link.allow_tags = True
     export_all_link.short_description = ''
 
-
     def change_view(self, request, object_id, form_url='', extra_context=None):
         obj = self.get_object(request, unquote(object_id))
+        if obj:
+            #check if the form has file fields
+            extra_context = extra_context or {}
+            extra_context['has_files'] = obj.has_files()
 
-        #check if the form has file fields
-        extra_context = extra_context or {}
-        extra_context['has_files'] = obj.has_files()
-
-        for inline_class in self.inlines:
-            if inline_class.model == Field:
-                if obj.fields_name:
-                    inline_class.verbose_name = obj.fields_name
-                    inline_class.verbose_name_plural = obj.fields_name
-            elif inline_class.model == Pricing:
-                inline_class.verbose_name = obj.pricing_name
-                inline_class.verbose_name_plural = obj.pricing_name
+            for inline_class in self.inlines:
+                if inline_class.model == Field:
+                    if obj.fields_name:
+                        inline_class.verbose_name = obj.fields_name
+                        inline_class.verbose_name_plural = obj.fields_name
+                elif inline_class.model == Pricing:
+                    inline_class.verbose_name = obj.pricing_name
+                    inline_class.verbose_name_plural = obj.pricing_name
 
         return super(FormAdmin, self).change_view(request, object_id, form_url, extra_context)
 
@@ -140,14 +141,14 @@ class FormAdmin(TendenciBaseModelAdmin):
         Add the export view to urls.
         """
         urls = super(FormAdmin, self).get_urls()
-        extra_urls = patterns("",
-            url("^export/(?P<form_id>\d+)/$",
+        extra_urls = [
+            url(r'^export/(?P<form_id>\d+)/$',
                 self.admin_site.admin_view(self.export_view),
                 name="forms_form_export"),
-            url("^file/(?P<field_entry_id>\d+)/$",
+            url(r'^file/(?P<field_entry_id>\d+)/$',
                 self.admin_site.admin_view(self.file_view),
                 name="forms_form_file"),
-        )
+        ]
         return extra_urls + urls
 
     def export_view(self, request, form_id):
@@ -155,59 +156,16 @@ class FormAdmin(TendenciBaseModelAdmin):
         Output a CSV file to the browser containing the entries for the form.
         """
         form = get_object_or_404(Form, id=form_id)
-        response = HttpResponse(mimetype="text/csv")
-        csvname = "%s-%s.csv" % (form.slug, slugify(datetime.now().ctime()))
-        response["Content-Disposition"] = "attachment; filename=%s" % csvname
-        csv = writer(response)
+        response = HttpResponse(content_type='text/csv')
+        csvname = '%s-%s.csv' % (form.slug, slugify(datetime.now().ctime()))
+        response['Content-Disposition'] = 'attachment; filename="%s"' % csvname
+        csv_writer = writer(response)
         # Write out the column names and store the index of each field
         # against its ID for building each entry row. Also store the IDs of
         # fields with a type of FileField for converting their field values
-        # into download URLs.
-        columns = []
-        field_indexes = {}
-        file_field_ids = []
-        for field in form.fields.all().order_by('position', 'id'):
-            columns.append(field.label.encode("utf-8"))
-            field_indexes[field.id] = len(field_indexes)
-            if field.field_type == "FileField":
-                file_field_ids.append(field.id)
-        entry_time_name = FormEntry._meta.get_field("entry_time").verbose_name
-        columns.append(unicode(entry_time_name))
-        if form.custom_payment:
-            columns.append(unicode("Pricing"))
-            columns.append(unicode("Price"))
-            columns.append(unicode("Payment Method"))
-        csv.writerow(columns)
-        # Loop through each field value order by entry, building up each
-        # entry as a row.
-        entries = FormEntry.objects.filter(form=form).order_by('pk')
-        for entry in entries:
-            values = FieldEntry.objects.filter(entry=entry)
-            row = [""] * len(columns)
-            entry_time = entry.entry_time.strftime("%Y-%m-%d %H:%M:%S")
-
-            if form.custom_payment:
-                if entry.pricing:
-                    row[-4] = entry_time
-                    row[-3] = entry.pricing.label
-                    row[-2] = entry.pricing.price
-                row[-1] = entry.payment_method
-            else:
-                row[-1] = entry_time
-
-            for field_entry in values:
-                value = field_entry.value.encode("utf-8")
-                # Create download URL for file fields.
-                if field_entry.field_id in file_field_ids:
-                    url = reverse("admin:forms_form_file", args=(field_entry.id,))
-                    value = request.build_absolute_uri(url)
-                # Only use values for fields that currently exist for the form.
-                try:
-                    row[field_indexes[field_entry.field_id]] = value
-                except KeyError:
-                    pass
-            # Write out the row.
-            csv.writerow(row)
+        
+        form_entries_to_csv_writer(csv_writer, form)
+        
         return response
 
     def file_view(self, request, field_entry_id):
@@ -228,15 +186,35 @@ class FormAdmin(TendenciBaseModelAdmin):
         data = default_storage.open(field.value).read()
         f = ContentFile(data)
 
-        response = HttpResponse(f.read(), mimetype=mime_type)
-        response['Content-Disposition'] = 'filename=%s' % base_name
+        response = HttpResponse(f.read(), content_type=mime_type)
+        response['Content-Disposition'] = 'filename="%s"' % base_name
         return response
 
 
-    def save_formset(self, request, form, formset, change):
-        instances = formset.save(commit=False)
-        for instance in instances:
-            instance.object_id = instance.form.pk
-            instance.save()
+class FormEntryAdmin(admin.ModelAdmin):
+    model = FormEntry
+    list_display = ['entry_time', 'form', 'first_name', 'last_name', 'email']
+    list_filter = ['form']
+    ordering = ("-entry_time",)
+
+    def first_name(self, instance):
+        return instance.get_first_name()
+    
+    def last_name(self, instance):
+        return instance.get_last_name()
+    
+    def email(self, instance):
+        return instance.get_email_address()
+
+    def has_add_permission(self, request):
+        return False
+    
+    def change_view(self, request, object_id, form_url='',
+                    extra_context=None):
+        return HttpResponseRedirect(
+                    reverse('form_entry_detail', args=[object_id])
+                )
+
 
 admin.site.register(Form, FormAdmin)
+admin.site.register(FormEntry, FormEntryAdmin)
