@@ -1,18 +1,59 @@
 from datetime import datetime, date, time
 import time as ttime
-import csv
+from io import BytesIO
+from xhtml2pdf import pisa
 
 from django.contrib.auth.models import User
 from django.core.files.storage import default_storage
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.template.loader import render_to_string
-from django.utils.encoding import smart_str
+from django.template.loader import get_template
 
 from tendenci.apps.invoices.models import Invoice
-from tendenci.core.base.utils import UnicodeWriter
-from tendenci.core.emails.models import Email
-from tendenci.core.site_settings.utils import get_setting
+from tendenci.apps.base.utils import UnicodeWriter
+from tendenci.apps.emails.models import Email
+from tendenci.apps.site_settings.utils import get_setting
 
+def invoice_pdf(request, invoice):
+    obj = invoice.get_object()
+    if obj:
+        obj_name = obj._meta.verbose_name
+    else:
+        obj_name = ''
+
+    payment_method = ""
+    if invoice.balance <= 0:
+        if invoice.payment_set:
+            payment_set = invoice.payment_set.order_by('-id')
+            if payment_set:
+                payment = payment_set[0]
+                payment_method = payment.method
+    tmp_total = 0
+    if invoice.variance and invoice.variance != 0:
+        tmp_total = invoice.subtotal
+        if invoice.tax:
+            tmp_total += invoice.tax
+        if invoice.shipping:
+            tmp_total += invoice.shipping
+        if invoice.shipping_surcharge:
+            tmp_total += invoice.shipping_surcharge
+        if invoice.box_and_packing:
+            tmp_total += invoice.box_and_packing
+
+    template_name="invoices/pdf.html"
+    template = get_template(template_name)
+    html  = template.render(context={
+                             'invoice': invoice,
+                             'obj_name': obj_name,
+                             'payment_method': payment_method,
+                             'tmp_total': tmp_total,
+                             'pdf_version': True,
+                            }, request=request)
+    result = BytesIO()
+    pisa.pisaDocument(BytesIO(html.encode("utf-8")), result)
+    #pisa.pisaDocument(BytesIO(html.encode("utf-8")), result,
+    #                  path=get_setting('site', 'global', 'siteurl'))
+    return result
 
 def process_invoice_export(start_dt=None, end_dt=None,
                            identifier=u'', user_id=0):
@@ -110,9 +151,6 @@ def process_invoice_export(start_dt=None, end_dt=None,
                         item = item.strftime('%Y-%m-%d')
                     elif isinstance(item, time):
                         item = item.strftime('%H:%M:%S')
-                    elif isinstance(item, basestring):
-                        item = item.encode("utf-8")
-                item = smart_str(item).decode('utf-8')
                 items_list.append(item)
             csv_writer.writerow(items_list)
 
@@ -139,15 +177,14 @@ def process_invoice_export(start_dt=None, end_dt=None,
             'end_dt': end_dt}
 
         subject = render_to_string(
-            'invoices/notices/export_ready_subject.html', parms)
+            template_name='invoices/notices/export_ready_subject.html', context=parms)
         subject = subject.strip('\n').strip('\r')
 
         body = render_to_string(
-            'invoices/notices/export_ready_body.html', parms)
+            template_name='invoices/notices/export_ready_body.html', context=parms)
 
         email = Email(
             recipient=user.email,
             subject=subject,
             body=body)
         email.send()
-
