@@ -1,13 +1,13 @@
-from tendenci.core.registry import site
-from tendenci.core.registry.base import CoreRegistry, lazy_reverse
+from tendenci.apps.registry.sites import site
+from tendenci.apps.registry.base import CoreRegistry, lazy_reverse
 from tendenci.apps.navs.models import Nav
 from django.utils.translation import ugettext_lazy as _
 
 
 class NavRegistry(CoreRegistry):
     version = '1.0'
-    author = _('Schipul - The Web Marketing Company')
-    author_email = 'programmers@schipul.com'
+    author = _('Tendenci - The Open Source AMS for Associations')
+    author_email = 'programmers@tendenci.com'
     description = _('Create navs for navigation')
 
     url = {
