@@ -1,34 +1,41 @@
 from django.db import models
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.contenttypes import generic
+from django.contrib.contenttypes.fields import GenericRelation
 
-from tendenci.core.perms.object_perms import ObjectPermission
-from tendenci.core.perms.models import TendenciBaseModel
+from tendenci.apps.perms.object_perms import ObjectPermission
+from tendenci.apps.perms.models import TendenciBaseModel
 from tendenci.apps.pages.models import Page
 from tendenci.apps.navs.managers import NavManager
 from tendenci.apps.navs.signals import update_nav_links
 from tendenci.libs.abstracts.models import OrderingBaseModel
+from tendenci.apps.navs.utils import clear_nav_cache
 
 class Nav(TendenciBaseModel):
-    class Meta:
-        permissions = (("view_nav",_("Can view nav")),)
-
     title = models.CharField(max_length=100)
     description = models.TextField(blank=True, null=True)
     megamenu = models.BooleanField(default=False)
 
-    perms = generic.GenericRelation(ObjectPermission,
+    perms = GenericRelation(ObjectPermission,
                                           object_id_field="object_id",
                                           content_type_field="content_type")
 
     objects = NavManager()
 
-    def __unicode__(self):
+    class Meta:
+#         permissions = (("view_nav",_("Can view nav")),)
+        app_label = 'navs'
+
+    def __str__(self):
         return self.title
 
-    @models.permalink
     def get_absolute_url(self):
-        return('navs.detail', [self.pk])
+        return reverse('navs.detail', args=[self.pk])
+
+    def save(self, *args, **kwargs):
+        super(Nav, self).save(*args, **kwargs)
+        # reset nav cache
+        clear_nav_cache(self)
 
     @property
     def top_items(self):
@@ -38,16 +45,19 @@ class Nav(TendenciBaseModel):
         return self.navitem_set.filter(level=0).order_by('position')
 
 class NavItem(OrderingBaseModel):
-    nav = models.ForeignKey(Nav)
+    nav = models.ForeignKey(Nav, on_delete=models.CASCADE)
     label = models.CharField(max_length=100)
     title = models.CharField(_("Title Attribute"), max_length=100, blank=True, null=True)
     new_window = models.BooleanField(_("Open in a new window"), default=False)
     css = models.CharField(_("CSS Class"), max_length=100, blank=True, null=True)
     level = models.IntegerField(default=0)
-    page = models.ForeignKey(Page, null=True)
+    page = models.ForeignKey(Page, null=True, on_delete=models.CASCADE)
     url = models.CharField(_("URL"), max_length=200, blank=True, null=True)
 
-    def __unicode__(self):
+    class Meta:
+        app_label = 'navs'
+
+    def __str__(self):
         return '%s - %s' % (self.nav.title, self.label)
 
     def get_url(self):
@@ -114,7 +124,7 @@ class NavItem(OrderingBaseModel):
         else:
             #first item
             next = range(0, self.level+1)
-        return next
+        return list(next)
 
     @property
     def prev_range(self):
@@ -123,7 +133,7 @@ class NavItem(OrderingBaseModel):
         else:
             #last item
             prev = range(0, self.level+1)
-        return prev
+        return list(prev)
 
 # Update page nav items when a page is saved
 models.signals.post_save.connect(update_nav_links, sender=Nav)
