@@ -1,13 +1,15 @@
+from builtins import str
 from django.template import Library, TemplateSyntaxError, Variable, Node
 from django.utils.translation import ugettext_lazy as _
-from tendenci.core.base.template_tags import ListNode, parse_tag_kwargs
-from tendenci.core.perms.utils import get_query_filters
+from tendenci.apps.base.template_tags import ListNode, parse_tag_kwargs
+from tendenci.apps.perms.utils import get_query_filters
 from django.contrib.auth.models import AnonymousUser, User
 from tendenci.apps.navs.models import Nav
 from tendenci.apps.navs.utils import get_nav, cache_nav
 
 register = Library()
 
+
 @register.inclusion_tag("navs/options.html", takes_context=True)
 def nav_options(context, user, nav):
     context.update({
@@ -16,6 +18,7 @@ def nav_options(context, user, nav):
     })
     return context
 
+
 @register.inclusion_tag("navs/nav.html", takes_context=True)
 def nav_nav(context, user, nav=None):
     context.update({
@@ -24,10 +27,12 @@ def nav_nav(context, user, nav=None):
     })
     return context
 
+
 @register.inclusion_tag("navs/search-form.html", takes_context=True)
 def nav_search(context):
     return context
 
+
 @register.inclusion_tag("navs/navigation.html", takes_context=True)
 def navigation(context, nav_id):
     """
@@ -50,7 +55,7 @@ def navigation(context, nav_id):
     try:
         filters = get_query_filters(user, 'navs.view_nav')
         navs = Nav.objects.filter(filters).filter(id=nav_id)
-        if user.is_authenticated():
+        if user.is_authenticated:
             if not user.profile.is_superuser:
                 navs = navs.distinct()
         nav = navs[0]
@@ -62,13 +67,17 @@ def navigation(context, nav_id):
     })
     return context
 
+
 @register.inclusion_tag("navs/load_nav.html", takes_context=True)
-def load_nav(context, nav_id, show_title=False):
+def load_nav(context, nav_id, show_title=False, **kwargs):
     """
     Renders the nav and its nav items.
     This will call nav_item that will call itself recursively nesting
     the subnavs
     """
+    is_site_map = kwargs.get('is_site_map', False)
+    is_bootstrap = kwargs.get('is_bootstrap', False)
+
     # No perms check because load_nav is only called by the other tags
     try:
         nav = Nav.objects.get(id=nav_id)
@@ -78,27 +87,76 @@ def load_nav(context, nav_id, show_title=False):
         "nav": nav,
         "items": nav.top_items,
         "show_title": show_title,
+        "is_bootstrap": is_bootstrap,
+        'is_site_map': is_site_map,
     })
     return context
 
+
 @register.inclusion_tag("navs/navigation_item.html", takes_context=True)
-def nav_item(context, item):
+def nav_item(context, item, **kwargs):
     """
         Renders a nav item and its children.
     """
+    is_bootstrap = kwargs.get('is_bootstrap', False)
+    is_site_map = kwargs.get('is_site_map', False)
     context.update({
         "item": item,
+        "is_bootstrap": is_bootstrap,
+        "is_site_map": is_site_map
     })
     return context
 
+
 @register.inclusion_tag("navs/cached_nav.html", takes_context=True)
-def nav(context, nav_id, show_title=False):
+def nav(context, nav_id, show_title=False, is_site_map=False):
 
     """
     Renders the nav from cache
     if not will use the navigation tag for rendering the nav
     """
     user = AnonymousUser()
+    if is_site_map == 'False':
+        is_site_map = False
+
+    if 'user' in context:
+        if isinstance(context['user'], User):
+            user = context['user']
+
+    try:
+        nav_id = Variable(nav_id)
+        nav_id = nav_id.resolve(context)
+    except:
+        pass
+
+    try:
+        filters = get_query_filters(user, 'navs.view_nav')
+        navs = Nav.objects.filter(filters).filter(id=nav_id)
+        if user.is_authenticated:
+            if not user.profile.is_superuser:
+                navs = navs.distinct()
+
+        nav_object = navs[0]
+        nav = get_nav(nav_object.pk, is_site_map=is_site_map)
+        if not nav:
+            nav = cache_nav(nav_object, show_title, is_site_map=is_site_map)
+    except:
+        return None
+
+    context.update({
+        "cached": nav,
+        "nav_id": nav_id,
+        "show_title": show_title,
+    })
+    return context
+
+
+@register.inclusion_tag("navs/cached_nav.html", takes_context=True)
+def bootstrap_nav(context, nav_id, show_title=False):
+    """
+    Bootstrap version of the nav tag
+    """
+    user = AnonymousUser()
 
     if 'user' in context:
         if isinstance(context['user'], User):
@@ -113,7 +171,7 @@ def nav(context, nav_id, show_title=False):
     try:
         filters = get_query_filters(user, 'navs.view_nav')
         navs = Nav.objects.filter(filters).filter(id=nav_id)
-        if user.is_authenticated():
+        if user.is_authenticated:
             if not user.profile.is_superuser:
                 navs = navs.distinct()
 
@@ -128,6 +186,7 @@ def nav(context, nav_id, show_title=False):
         "cached": nav,
         "nav_id": nav_id,
         "show_title": show_title,
+        "is_bootstrap": True   # added context to enable to indicate bootstrap nav will be used
     })
     return context
 
@@ -211,7 +270,7 @@ class GetNavNode(Node):
         try:
             filters = get_query_filters(user, 'navs.view_nav')
             nav = Nav.objects.filter(filters).filter(pk=pk)
-            if user.is_authenticated():
+            if user.is_authenticated:
                 if not user.profile.is_superuser:
                     nav = nav.distinct()
 
@@ -219,7 +278,7 @@ class GetNavNode(Node):
         except:
             pass
 
-        return unicode()
+        return str()
 
 
 @register.tag
