@@ -1,9 +1,10 @@
-from django.contrib import admin
-from django.core.urlresolvers import reverse
-from django.utils.translation import ugettext_lazy as _
 
-from tendenci.apps.notifications.models import (NoticeType, NoticeSetting, Notice,
-    ObservedItem, NoticeEmail)
+from django.contrib import admin
+from django.urls import reverse
+from django.utils.translation import ugettext_lazy as _
+from django.utils.safestring import mark_safe
+
+from tendenci.apps.notifications.models import NoticeEmail
 
 
 class NoticeTypeAdmin(admin.ModelAdmin):
@@ -17,7 +18,7 @@ class NoticeTypeAdmin(admin.ModelAdmin):
 
     def __init__(self, *args, **kwargs):
         super(NoticeTypeAdmin, self).__init__(*args, **kwargs)
-        self.list_display_links = (None, )
+        self.list_display_links = ()
 
 
 class NoticeSettingAdmin(admin.ModelAdmin):
@@ -38,15 +39,15 @@ class NoticeEmailAdmin(admin.ModelAdmin):
     def has_view_permission(self, request, obj=None):
         return False
 
+    @mark_safe
     def preview_email(self, obj):
         return '<a href="%s">%s</a>' % \
             (reverse('notification_email', args=[obj.guid]), obj.title)
-    preview_email.allow_tags = True
     preview_email.short_description = _('Preview Email')
 
     def resend(self, request, queryset):
         for q in queryset:
-            print q.resend()
+            print(q.resend())
     resend.short_description = _("Resend the selected emails")
 
     def has_change_permission(self, request, obj=None):
@@ -54,7 +55,7 @@ class NoticeEmailAdmin(admin.ModelAdmin):
 
     def __init__(self, *args, **kwargs):
         super(NoticeEmailAdmin, self).__init__(*args, **kwargs)
-        self.list_display_links = (None, )
+        self.list_display_links = ()
 
 # admin.site.register(NoticeType, NoticeTypeAdmin)
 # admin.site.register(NoticeSetting, NoticeSettingAdmin)
