@@ -1,17 +1,17 @@
-from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
-from tendenci.core.registry import site
-from tendenci.core.registry.base import CoreRegistry, lazy_reverse
+from tendenci.apps.registry.sites import site
+from tendenci.apps.registry.base import CoreRegistry, lazy_reverse
 from tendenci.apps.pages.models import Page
+from tendenci.apps.theme.templatetags.static import static
 
 
 class PageRegistry(CoreRegistry):
     version = '1.0'
-    author = _('Schipul - The Web Marketing Company')
-    author_email = 'programmers@schipul.com'
+    author = _('Tendenci - The Open Source AMS for Associations')
+    author_email = 'programmers@tendenci.com'
     description = _('Create pages to display basic content throughout the site')
-    icon = '%simages/icons/pages-color-64x64.png' % settings.STATIC_URL
+    icon = static('images/icons/pages-color-64x64.png')
 
     event_logs = {
         'page':{
