@@ -2,19 +2,16 @@ import imghdr
 from os.path import splitext, basename
 
 from tendenci.apps.pages.models import Page
-from tendenci.core.perms.forms import TendenciBaseForm
+from tendenci.apps.perms.forms import TendenciBaseForm
 
 from django.utils.safestring import mark_safe
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 from django.template.defaultfilters import filesizeformat
 
-from tinymce.widgets import TinyMCE
-from tendenci.core.base.utils import get_template_list
-from tendenci.core.files.utils import get_max_file_upload_size
-
-template_choices = [('default.html',_('Default'))]
-template_choices += get_template_list()
+from tendenci.libs.tinymce.widgets import TinyMCE
+from tendenci.apps.base.utils import get_template_list
+from tendenci.apps.files.utils import get_max_file_upload_size
 
 ALLOWED_IMG_EXT = (
     '.jpg',
@@ -32,11 +29,15 @@ class PageAdminForm(TendenciBaseForm):
     content = forms.CharField(required=False,
         widget=TinyMCE(attrs={'style':'width:100%'},
         mce_attrs={'storme_app_label':Page._meta.app_label,
-        'storme_model':Page._meta.module_name.lower()}))
+        'storme_model':Page._meta.model_name.lower()}))
+
+    syndicate = forms.BooleanField(label=_('Include in RSS Feed'), required=False, initial=True)
 
     status_detail = forms.ChoiceField(
         choices=(('active',_('Active')),('inactive',_('Inactive')), ('pending',_('Pending')),))
 
+    template_choices = [('default.html',_('Default'))]
+    template_choices += get_template_list()
     template = forms.ChoiceField(choices=template_choices)
 
     meta_title = forms.CharField(required=False)
@@ -79,9 +80,19 @@ class PageAdminForm(TendenciBaseForm):
         else:
             self.fields['content'].widget.mce_attrs['app_instance_id'] = 0
 
-        template_choices = [('default.html',_('Default'))]
-        template_choices += get_template_list()
-        self.fields['template'].choices = template_choices
+    def clean_syndicate(self):
+        """
+        clean method for syndicate added due to the update
+        done on the field BooleanField -> NullBooleanField
+        NOTE: BooleanField is converted to NullBooleanField because
+        some Boolean data has value of None than False. This was updated
+        on Django 1.6. BooleanField cannot have a value of None.
+        """
+        data = self.cleaned_data.get('syndicate', False)
+        if data:
+            return True
+        else:
+            return False
 
     def clean(self):
         cleaned_data = super(PageAdminForm, self).clean()
@@ -109,17 +120,20 @@ class PageForm(TendenciBaseForm):
     content = forms.CharField(required=False,
         widget=TinyMCE(attrs={'style':'width:100%'},
         mce_attrs={'storme_app_label':Page._meta.app_label,
-        'storme_model':Page._meta.module_name.lower()}))
+        'storme_model':Page._meta.model_name.lower()}))
 
     contributor_type = forms.ChoiceField(choices=CONTRIBUTOR_CHOICES,
                                          initial=Page.CONTRIBUTOR_AUTHOR,
                                          widget=forms.RadioSelect())
+
+    syndicate = forms.BooleanField(label=_('Include in RSS Feed'), required=False, initial=True)
+
     status_detail = forms.ChoiceField(
         choices=(('active', _('Active')), ('inactive', _('Inactive')), ('pending', _('Pending'))))
 
     tags = forms.CharField(required=False, help_text=mark_safe('<a href="/tags/" target="_blank">%s</a>' % _('Open All Tags list in a new window')))
 
-    template = forms.ChoiceField(choices=template_choices)
+    template = forms.ChoiceField(choices=[])
 
     class Meta:
         model = Page
@@ -131,7 +145,6 @@ class PageForm(TendenciBaseForm):
         'template',
         'group',
         'contributor_type',
-        'google_profile',
         'allow_anonymous_view',
         'syndicate',
         'user_perms',
@@ -152,8 +165,7 @@ class PageForm(TendenciBaseForm):
                       'legend': ''
                       }),
                       (_('Contributor'), {
-                       'fields': ['contributor_type',
-                                  'google_profile'],
+                       'fields': ['contributor_type',],
                        'classes': ['boxy-grey'],
                       }),
                       (_('Permissions'), {
@@ -170,6 +182,38 @@ class PageForm(TendenciBaseForm):
                       'classes': ['admin-only'],
                     })]
 
+    def __init__(self, *args, **kwargs):
+        super(PageForm, self).__init__(*args, **kwargs)
+        if self.instance.header_image:
+            self.fields['header_image'].help_text = '<input name="remove_photo" id="id_remove_photo" type="checkbox"/> %s: <a target="_blank" href="/files/%s/">%s</a>' % (_('Remove current image'), self.instance.header_image.pk, basename(self.instance.header_image.file.name))
+        else:
+            self.fields.pop('remove_photo')
+
+        if self.instance.pk:
+            self.fields['content'].widget.mce_attrs['app_instance_id'] = self.instance.pk
+        else:
+            self.fields['content'].widget.mce_attrs['app_instance_id'] = 0
+
+        if not self.user.profile.is_superuser:
+            if 'syndicate' in self.fields: self.fields.pop('syndicate')
+            if 'status_detail' in self.fields: self.fields.pop('status_detail')
+
+        self.fields['template'].choices = [('default.html',_('Default'))] + get_template_list()
+
+    def clean_syndicate(self):
+        """
+        clean method for syndicate added due to the update
+        done on the field BooleanField -> NullBooleanField
+        NOTE: BooleanField is converted to NullBooleanField because
+        some Boolean data has value of None than False. This was updated
+        on Django 1.6. BooleanField cannot have a value of None.
+        """
+        data = self.cleaned_data.get('syndicate', False)
+        if data:
+            return True
+        else:
+            return False
+
     def clean(self):
         cleaned_data = super(PageForm, self).clean()
         slug = cleaned_data.get('slug')
@@ -211,27 +255,6 @@ class PageForm(TendenciBaseForm):
 
         return header_image
 
-    def __init__(self, *args, **kwargs):
-        super(PageForm, self).__init__(*args, **kwargs)
-        if self.instance.header_image:
-            self.fields['header_image'].help_text = '<input name="remove_photo" id="id_remove_photo" type="checkbox"/> %s: <a target="_blank" href="/files/%s/">%s</a>' % (_('Remove current image'), self.instance.header_image.pk, basename(self.instance.header_image.file.name))
-        else:
-            self.fields.pop('remove_photo')
-
-        if self.instance.pk:
-            self.fields['content'].widget.mce_attrs['app_instance_id'] = self.instance.pk
-        else:
-            self.fields['content'].widget.mce_attrs['app_instance_id'] = 0
-
-        template_choices = [('default.html',_('Default'))]
-        template_choices += get_template_list()
-        self.fields['template'].choices = template_choices
-        self.fields['google_profile'].help_text = mark_safe(GOOGLE_PLUS_HELP_TEXT)
-
-        if not self.user.profile.is_superuser:
-            if 'syndicate' in self.fields: self.fields.pop('syndicate')
-            if 'status_detail' in self.fields: self.fields.pop('status_detail')
-
     def save(self, *args, **kwargs):
         page = super(PageForm, self).save(*args, **kwargs)
         if self.cleaned_data.get('remove_photo'):
