@@ -1,5 +1,5 @@
 import re
-import HTMLParser
+from html import parser as html_parser
 from django.core.management.base import BaseCommand
 
 
@@ -17,8 +17,8 @@ class Command(BaseCommand):
         from tendenci.apps.pages.models import Page
 
         pages = Page.objects.all()
-        self.h = HTMLParser.HTMLParser()
-        pattern = re.compile('(&#\d+;)', re.IGNORECASE)
+        self.h = html_parser.HTMLParser()
+        pattern = re.compile(r'(&#\d+;)', re.IGNORECASE)
 
         for page in pages:
             page.title = re.sub(pattern, self.unescape, page.title)
