@@ -1,10 +1,8 @@
-import os
-import re
+
 import requests
-from urlparse import urlparse
 from requests.exceptions import (
     MissingSchema, InvalidSchema, InvalidURL, ConnectionError)
-from BeautifulSoup import BeautifulSoup
+from bs4 import BeautifulSoup
 from requests.packages.urllib3.exceptions import LocationParseError
 from django.core.management.base import BaseCommand
 
@@ -67,7 +65,7 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         from tendenci.apps.pages.models import Page
-        from tendenci.core.site_settings.utils import get_setting
+        from tendenci.apps.site_settings.utils import get_setting
 
         self.SITE_URL = get_setting('site', 'global', 'siteurl')
 
@@ -75,14 +73,14 @@ class Command(BaseCommand):
 
             soup = BeautifulSoup(page.content)
 
-            links = soup.findAll('a')
-            # images = soup.findAll('img')
+            links = soup.find_all('a')
+            # images = soup.find_all('img')
 
             broken_links = self.get_broken_links(links)
             # broken_images = self.get_broken_images(images)
 
-            # print page.slug,
-            # print 'images', '%s/%s' % (len(images), len(broken_images)),
-            # print 'links', '%s/%s' % (len(links), len(broken_links)), broken_links
+            # print(page.slug)
+            # print('images', '%s/%s' % (len(images), len(broken_images)))
+            # print('links', '%s/%s' % (len(links), len(broken_links)), broken_links)
 
-            print page.slug, broken_links
+            print(page.slug, broken_links)
