@@ -3,9 +3,9 @@ from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth.models import User
 from django.utils.translation import ugettext as _
 
-from tendenci.core.event_logs.models import EventLog
-from tendenci.core.perms.admin import TendenciBaseModelAdmin
-from tendenci.core.perms.utils import update_perms_and_save
+from tendenci.apps.event_logs.models import EventLog
+from tendenci.apps.perms.admin import TendenciBaseModelAdmin
+from tendenci.apps.perms.utils import update_perms_and_save
 from tendenci.apps.profiles.models import Profile
 from tendenci.apps.profiles.forms import ProfileAdminForm
 
@@ -66,6 +66,14 @@ class ProfileAdmin(TendenciBaseModelAdmin):
 
     ordering = ('user__last_name', 'user__first_name')
 
+    def get_object(self, request, object_id, from_field=None):
+        obj = super(ProfileAdmin, self).get_object(request, object_id, from_field=from_field)
+        # Avoid language being accidentally set to the first option 'ar'
+        # because en-us is not an option in the language dropdown
+        if obj and obj.language == 'en-us':
+            obj.language = 'en'
+        return obj
+
     def save_model(self, request, object, form, change):
         instance = form.save(request=request, commit=False)
         instance = update_perms_and_save(request, form, instance, log=False)
@@ -108,6 +116,8 @@ admin.site.register(Profile, ProfileAdmin)
 
 
 class MyUserAdmin(UserAdmin):
+    list_display = ('id', 'username', 'email', 'first_name', 'last_name',
+                    'show_member_number', 'is_staff', 'is_superuser', 'is_active')
     fieldsets = (
         (None, {'fields': ('username', 'password')}),
         (_('Personal info'), {'fields': ('first_name', 'last_name', 'email')}),
@@ -116,6 +126,14 @@ class MyUserAdmin(UserAdmin):
         (_('Permissions'), {'fields': ('user_permissions',)}),
         (_('Important dates'), {'fields': ('last_login', 'date_joined')}),
     )
+    ordering = ('-id',)
+    
+    def show_member_number(self, instance):
+        [member_number] = Profile.objects.filter(user=instance).values_list('member_number', flat=True)[:1] or ['']
+        return member_number
+
+    show_member_number.short_description = 'Member number'
+    show_member_number.admin_order_field = 'profile__member_number'
 
 admin.site.unregister(User)
 admin.site.register(User, MyUserAdmin)
