@@ -1,3 +1,4 @@
+
 from datetime import datetime
 import traceback
 from django.core.management.base import BaseCommand
@@ -16,13 +17,19 @@ class Command(BaseCommand):
         python manage.py import_users 10 1
     """
 
+    def add_arguments(self, parser):
+        parser.add_argument('import_id', type=int)
+        parser.add_argument('user_id', type=int)
+
     def handle(self, *args, **options):
         from tendenci.apps.profiles.models import UserImport, UserImportData
         from tendenci.apps.profiles.utils import ImportUsers
         from tendenci.apps.user_groups.models import GroupMembership
 
-        uimport = get_object_or_404(UserImport, pk=args[0])
-        request_user = User.objects.get(pk=args[1])
+        import_id = options['import_id']
+        user_id = options['user_id']
+        uimport = get_object_or_404(UserImport, pk=import_id)
+        request_user = User.objects.get(pk=user_id)
         data_list = UserImportData.objects.filter(uimport=uimport).order_by('pk')
         imu = ImportUsers(request_user, uimport, dry_run=False)
 
@@ -30,12 +37,11 @@ class Command(BaseCommand):
         if uimport.group_id and uimport.clear_group_membership:
             GroupMembership.objects.filter(group_id=uimport.group_id).delete()
 
-
         for idata in data_list:
             try:
                 imu.process_user(idata)
-            except Exception, e:
-                print traceback.format_exc()
+            except Exception:
+                print(traceback.format_exc())
 
             uimport.num_processed += 1
 
@@ -54,4 +60,3 @@ class Command(BaseCommand):
 
         # generate a recap file
         uimport.generate_recap()
-
