@@ -1,10 +1,11 @@
+
 import mimetypes
 from django.core.management.base import BaseCommand
 from django.core.files.base import ContentFile
 from django.core.files.storage import default_storage
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth.models import User
-from avatar.models import Avatar, avatar_file_path
+
 
 class Command(BaseCommand):
     """
@@ -14,7 +15,8 @@ class Command(BaseCommand):
     """
 
     def handle(self, *args, **options):
-        from tendenci.core.files.models import File as tFile
+        from avatar.models import Avatar, avatar_file_path
+        from tendenci.apps.files.models import File as tFile
 
         ct_user = ContentType.objects.get_for_model(User)
         tfiles = tFile.objects.filter(content_type=ct_user,
@@ -44,5 +46,5 @@ class Command(BaseCommand):
                                 primary=True,
                                 avatar=avatar_path
                                     )
-                            print 'Avatar created for ', user
-        print 'Done'
+                            print('Avatar created for ', user)
+        print('Done')
