@@ -1,19 +1,26 @@
 import os
 import uuid
+import hashlib
+import re
+from urllib.parse import urlencode
 
 from django.db import models
+from django.urls import reverse
 from django.contrib.auth.models import User
 from django.utils.translation import ugettext_lazy as _
 from django.core.files.storage import default_storage
-from django.utils.encoding import smart_str
 from django.conf import settings
+from django.db import connection, ProgrammingError
 
-from tendenci.core.base.utils import create_salesforce_contact
+from tendenci.apps.base.utils import create_salesforce_contact
 from tendenci.apps.profiles.managers import ProfileManager, ProfileActiveManager
 from tendenci.apps.entities.models import Entity
-from tendenci.core.base.models import BaseImport, BaseImportData
-from tendenci.core.base.utils import UnicodeWriter
+from tendenci.apps.base.models import BaseImport, BaseImportData
+from tendenci.apps.base.utils import UnicodeWriter
 from tendenci.libs.abstracts.models import Person
+from tendenci.apps.site_settings.utils import get_setting
+from tendenci.apps.theme.templatetags.static import static
+from tendenci.apps.perms.utils import has_perm
 #from tendenci.apps.user_groups.models import Group
 
 
@@ -22,23 +29,37 @@ from tendenci.libs.abstracts.models import Person
 
 
 class Profile(Person):
+
+    SALUTATION_CHOICES = (
+        ('Mr.', _('Mr.')),
+        ('Mrs.', _('Mrs.')),
+        ('Ms.', _('Ms.')),
+        ('Miss', _('Miss')),
+        ('Dr.', _('Dr.')),
+        ('Prof.', _('Prof.')),
+        ('Hon.', _('Hon.')),
+    )
+
+    SEX_CHOICES = (
+        ('male', _(u'Male')),
+        ('female', _(u'Female'))
+    )
+
     # relations
     guid = models.CharField(max_length=40)
-    entity = models.ForeignKey(Entity, blank=True, null=True)
+    entity = models.ForeignKey(Entity, blank=True, null=True, on_delete=models.SET_NULL)
     pl_id = models.IntegerField(default=1)
     historical_member_number = models.CharField(_('historical member number'), max_length=50, blank=True)
 
     # profile meta data
-    salutation = models.CharField(_('salutation'), max_length=15,
-        blank=True, choices=(('Mr.', _('Mr.')),('Mrs.', _('Mrs.')),
-            ('Ms.', _('Ms.')),('Miss', _('Miss')),('Dr.', _('Dr.')),('Prof.', _('Prof.')),('Hon.', _('Hon.')),))
+    salutation = models.CharField(_('salutation'), max_length=15, blank=True, choices=SALUTATION_CHOICES)
     initials = models.CharField(_('initials'), max_length=50, blank=True)
     display_name = models.CharField(_('display name'), max_length=120, blank=True)
     mailing_name = models.CharField(_('mailing name'), max_length=120, blank=True)
     company = models.CharField(_('company'), max_length=100, blank=True)
     position_title = models.CharField(_('position title'), max_length=250, blank=True)
     position_assignment = models.CharField(_('position assignment'), max_length=50, blank=True)
-    sex = models.CharField(_('gender'), max_length=50, blank=True, choices=(('male', _(u'Male')),('female', _(u'Female'))))
+    sex = models.CharField(_('gender'), max_length=50, blank=True, choices=SEX_CHOICES)
     address_type = models.CharField(_('address type'), max_length=50, blank=True)
     phone2 = models.CharField(_('phone2'), max_length=50, blank=True)
     fax = models.CharField(_('fax'), max_length=50, blank=True)
@@ -52,11 +73,11 @@ class Profile(Person):
     ssn = models.CharField(_('social security number'), max_length=50, blank=True)
     spouse = models.CharField(_('spouse'), max_length=50, blank=True)
     department = models.CharField(_('department'), max_length=50, blank=True)
-    education = models.CharField(_('education'), max_length=100, blank=True)
+    education = models.CharField(_('highest level of education'), max_length=100, blank=True)
     student = models.IntegerField(_('student'), null=True, blank=True)
-    remember_login = models.BooleanField(_('remember login'))
-    exported = models.BooleanField(_('exported'))
-    direct_mail = models.BooleanField(_('direct mail'), default=False)
+    remember_login = models.BooleanField(_('remember login'), default=False)
+    exported = models.BooleanField(_('exported'), default=False)
+    direct_mail = models.BooleanField(_('direct mail'), default=True)
     notes = models.TextField(_('notes'), blank=True)
     admin_notes = models.TextField(_('admin notes'), blank=True)
     referral_source = models.CharField(_('referral source'), max_length=50, blank=True)
@@ -67,6 +88,13 @@ class Profile(Person):
     first_responder = models.BooleanField(_('first responder'), default=False)
     agreed_to_tos = models.BooleanField(_('agrees to tos'), default=False)
     original_username = models.CharField(max_length=50)
+    
+    # social media links
+    linkedin = models.URLField(_('LinkedIn'), blank=True, default='')
+    facebook = models.URLField(_('Facebook'), blank=True, default='')
+    twitter = models.URLField(_('Twitter'), blank=True, default='')
+    instagram = models.URLField(_('Instagram'), blank=True, default='')
+    youtube = models.URLField(_('YouTube'), blank=True, default='')
 
     sf_contact_id = models.CharField(max_length=100, blank=True, null=True)
 
@@ -78,24 +106,24 @@ class Profile(Person):
     actives = ProfileActiveManager()
 
     class Meta:
-        permissions = (("view_profile", _("Can view profile")),)
+#         permissions = (("view_profile", _("Can view profile")),)
         verbose_name = _("User")
         verbose_name_plural = _("Users")
+        app_label = 'profiles'
 
-    def __unicode__(self):
+    def __str__(self):
         if hasattr(self, 'user'):
             return self.user.username
         else:
             return u''
 
-    @models.permalink
     def get_absolute_url(self):
         from tendenci.apps.profiles.utils import clean_username
         cleaned_username = clean_username(self.user.username)
         if cleaned_username != self.user.username:
             self.user.username = cleaned_username
             self.user.save()
-        return ('profile', [self.user.username])
+        return reverse('profile', args=[self.user.username])
 
     def _can_login(self):
         """
@@ -126,7 +154,7 @@ class Profile(Person):
 
     @property
     def lang(self):
-        if not self.language in [l[0] for l in settings.LANGUAGES]:
+        if self.language not in [l[0] for l in settings.LANGUAGES]:
             self.language = 'en'
             self.save()
         return self.language
@@ -159,57 +187,100 @@ class Profile(Person):
 
     def save(self, *args, **kwargs):
         if not self.id:
-            self.guid = str(uuid.uuid1())
+            self.guid = str(uuid.uuid4())
 
         # match allow_anonymous_view with opposite of hide_in_search
         if self.hide_in_search:
             self.allow_anonymous_view = False
         else:
-            self.allow_anonymous_view = True
+            self.allow_anonymous_view = get_setting('module', 'users', 'allowanonymoususersearchuser')
+
+        self.allow_user_view =  get_setting('module', 'users', 'allowusersearch')
+        if get_setting('module', 'memberships', 'memberprotection') == 'private':
+            self.allow_member_view = False
+        else:
+            self.allow_member_view = True
 
         super(Profile, self).save(*args, **kwargs)
 
         try:
-            from tendenci.addons.campaign_monitor.utils import update_subscription
+            from tendenci.apps.campaign_monitor.utils import update_subscription
             if hasattr(self, 'old_email') and getattr(self, 'old_email') != self.user.email:
                 update_subscription(self, self.old_email)
                 del self.old_email
         except ImportError:
             pass
 
-    # if this profile allows view by user2_compare
+    def allow_search_users(self):
+        """
+        Check if this user can search users.
+        """
+        if self.is_superuser:
+            return True
+
+        # allow anonymous search users
+        if get_setting('module', 'users', 'allowanonymoususersearchuser'):
+            return True
+
+        # allow user search users
+        if get_setting('module', 'users', 'allowusersearch') \
+            and self.user.is_authenticated:
+            return True
+
+        # allow members search users/members
+        if get_setting('module', 'memberships', 'memberprotection') != 'private':
+            if self.user.is_authenticated and self.user.profile.is_member:
+                return True
+
+        return False
+
     def allow_view_by(self, user2_compare):
-        boo = False
-
-        if user2_compare.is_superuser:
-            boo = True
-        else:
-            if user2_compare == self.user:
-                boo = True
-            else:
-                if self.creator == user2_compare or self.owner == user2_compare:
-                    if self.status == 1:
-                        boo = True
-                else:
-                    if user2_compare.has_perm('profiles.view_profile', self):
-                        boo = True
-
-        return boo
-
-    # if this profile allows edit by user2_compare
-    def allow_edit_by(self, user2_compare):
+        """
+        Check if `user2_compare` is allowed to view this user.
+        """
+        # user2_compare is superuser
         if user2_compare.is_superuser:
             return True
-        else:
-            if user2_compare == self.user:
+
+        # this user is user2_compare self
+        if user2_compare == self.user:
+            return True
+
+        # user2_compare is creator or owner of this user
+        if (self.creator and self.creator == user2_compare) or \
+            (self.owner and self.owner == user2_compare):
+            if self.status:
                 return True
-            else:
-                if self.creator == user2_compare or self.owner == user2_compare:
-                    if self.status == 1:
-                        return True
-                else:
-                    if user2_compare.has_perm('profiles.change_profile', self):
-                        return True
+
+        # user2_compare can search users and has view perm
+        if user2_compare.profile.allow_search_users():
+            if user2_compare.has_perm('profiles.view_profile', self):
+                return True
+
+        if has_perm(user2_compare, 'profiles.view_profile'):
+            return True
+
+        # False for everythin else
+        return False
+
+    def allow_edit_by(self, user2_compare):
+        """
+        Check if `user2_compare` is allowed to edit this user.
+        """
+        if user2_compare.is_superuser:
+            return True
+
+        if user2_compare == self.user:
+            return True
+
+        if (self.creator and self.creator == user2_compare) or \
+            (self.owner and self.owner == user2_compare):
+            if self.status:
+                return True
+
+        if user2_compare.has_perm('profiles.change_profile', self):
+            return True
+
         return False
 
     def can_renew(self):
@@ -257,7 +328,7 @@ class Profile(Person):
     def get_groups(self):
         memberships = self.user.group_member.filter(group__status=True)
         return [membership.group for membership in memberships]
-    
+
     @property
     def membership(self):
         [membership] = self.user.membershipdefault_set.exclude(
@@ -274,6 +345,9 @@ class Profile(Person):
 
         self.member_number = u''
         if membership:
+            if not membership.member_number:
+                membership.set_member_number()
+                membership.save()
             self.member_number = membership.member_number
 
         self.save()
@@ -293,9 +367,10 @@ class Profile(Person):
 
         max_length = 8
         # the first argument is the class, exclude it
-        un = ' '.join(args[1:])             # concat args into one string
-        un = re.sub('\s+', '_', un)       # replace spaces w/ underscores
-        un = re.sub('[^\w.-]+', '', un)   # remove non-word-characters
+        un = ''.join(args[1:])             # concat args into one string
+        un =  un.lower()
+        un = re.sub(r'\s+', '', un)       # remove spaces
+        un = re.sub(r'[^\w.-]+', '', un)   # remove non-word-characters
         un = un.strip('_.- ')           # strip funny-characters from sides
         un = un[:max_length].lower()    # keep max length and lowercase username
 
@@ -310,7 +385,7 @@ class Profile(Person):
             # to kill the database username max field length
             un = '%s%s' % (un, str(max(others) + 1))
 
-        return un.lower()
+        return un
 
     @classmethod
     def get_or_create_user(cls, **kwargs):
@@ -353,7 +428,7 @@ class Profile(Person):
             user = User.objects.create_user(**{
                 'username': un or Profile.spawn_username(fn[:1], ln),
                 'email': em,
-                'password': pw or uuid.uuid1().get_hex()[:6],
+                'password': pw or uuid.uuid4().hex[:6],
             })
 
         user.first_name = fn
@@ -363,7 +438,7 @@ class Profile(Person):
 
         if created:
             profile = Profile.objects.create_profile(user)
-            sf_id = create_salesforce_contact(profile)
+            create_salesforce_contact(profile)  # Returns sf_id
 
         return user, created
 
@@ -393,6 +468,49 @@ class Profile(Person):
             if role in self.roles():
                 return role
 
+    def getMD5(self):
+        m = hashlib.md5()
+        m.update(self.user.email.encode())
+        return m.hexdigest()
+
+    def get_gravatar_url(self, size):
+        # Use old avatar, if exists, as the default
+        default = ''
+        if get_setting('module', 'users', 'useoldavatarasdefault'):
+            c = connection.cursor()
+            try:
+                c.execute("select avatar from avatar_avatar where \"primary\"='t' and user_id=%d" % self.user.id)
+                row = c.fetchone()
+                if row and os.path.exists(os.path.join(settings.MEDIA_ROOT, row[0])):
+                    default = '%s%s%s' %  (get_setting('site', 'global', 'siteurl'),
+                                       settings.MEDIA_URL,
+                                       row[0])
+            except ProgrammingError:
+                pass
+
+            c.close()
+
+        if not default:
+            # Gravatar doesn't accept the url to the default image from an IP address,
+            # as a result, it would show a broken avatar image.
+            # Use Gravatar's own default image for sites not having domains yet
+            site_url = get_setting('site', 'global', 'siteurl')
+            if re.match(r'(http://|https://)\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}', site_url):
+                default = ''
+            else:
+                default = '%s%s'%(site_url,
+                                static(settings.GAVATAR_DEFAULT_URL))
+
+        gravatar_url = "//www.gravatar.com/avatar/" + self.getMD5() + "?"
+        gravatar_url += urlencode({'d':default, 's':str(size)})
+        return gravatar_url
+
+
+def get_import_file_path(instance, filename):
+    return "imports/profiles/{uuid}/{filename}".format(
+                            uuid=uuid.uuid4().hex[:8],
+                            filename=filename)
+
 
 class UserImport(BaseImport):
     INTERACTIVE_CHOICES = (
@@ -400,19 +518,22 @@ class UserImport(BaseImport):
         (False, _('Not Interactive (no login)')),
     )
 
-    UPLOAD_DIR = "imports/profiles/%s" % uuid.uuid1().get_hex()[:8]
+#     UPLOAD_DIR = "imports/profiles/%s" % uuid.uuid4().hex[:8]
 
     upload_file = models.FileField(_("Upload File"), max_length=260,
-                                   upload_to=UPLOAD_DIR,
+                                   upload_to=get_import_file_path,
                                    null=True)
     recap_file = models.FileField(_("Recap File"), max_length=260,
-                                   upload_to=UPLOAD_DIR, null=True)
+                                   null=True)
 
     interactive = models.BooleanField(choices=INTERACTIVE_CHOICES, default=False)
     group_id = models.IntegerField(default=0)
 
     clear_group_membership = models.BooleanField(default=False)
 
+    class Meta:
+        app_label = 'profiles'
+
     def generate_recap(self):
         if not self.recap_file and self.header_line:
             file_name = 'user_import_%d_recap.csv' % self.id
@@ -433,7 +554,6 @@ class UserImport(BaseImport):
                 data_dict = idata.row_data
                 row = [data_dict[k] for k in header_row if k in data_dict]
                 row.extend([idata.action_taken, idata.error])
-                row = [smart_str(s).decode('utf-8') for s in row]
                 recap_writer.writerow(row)
 
             f.close()
@@ -442,4 +562,7 @@ class UserImport(BaseImport):
 
 
 class UserImportData(BaseImportData):
-    uimport = models.ForeignKey(UserImport, related_name="user_import_data")
+    uimport = models.ForeignKey(UserImport, related_name="user_import_data", on_delete=models.CASCADE)
+
+    class Meta:
+        app_label = 'profiles'
