@@ -1,3 +1,4 @@
+from builtins import str
 import re
 import time as ttime
 from datetime import datetime, date, time
@@ -11,40 +12,40 @@ import csv
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.files.storage import default_storage
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.db.models import Q
 from django.db.models.fields import AutoField
 from django.template.loader import render_to_string
 from django.utils.encoding import smart_str
+from django.utils.html import format_html
 from django.core import exceptions
 
 from tendenci.apps.profiles.models import Profile
 from tendenci.apps.user_groups.models import GroupMembership, Group
-from tendenci.core.base.utils import UnicodeWriter, normalize_newline
-from tendenci.core.emails.models import Email
-from tendenci.core.perms.utils import get_query_filters
-from tendenci.core.site_settings.utils import get_setting
+from tendenci.apps.base.utils import UnicodeWriter, normalize_newline
+from tendenci.apps.emails.models import Email
+from tendenci.apps.perms.utils import get_query_filters
+from tendenci.apps.site_settings.utils import get_setting
 
 
 def profile_edit_admin_notify(request, old_user, old_profile, profile, **kwargs):
-    from django.core.mail.message import EmailMessage
-    from django.template import RequestContext
 
     subject = 'User Account Modification Notice for %s' % get_setting('site', 'global', 'sitedisplayname')
-    body = render_to_string('profiles/edit_notice.txt',
-                               {'old_user':old_user,
+    body = render_to_string(template_name='profiles/edit_notice.txt',
+                               context={'old_user':old_user,
                                 'old_profile': old_profile,
                                 'profile': profile},
-                               context_instance=RequestContext(request))
+                               request=request)
 
     sender = settings.DEFAULT_FROM_EMAIL
     recipients = ['%s<%s>' % (r[0], r[1]) for r in settings.ADMINS]
-    msg = EmailMessage(subject, body, sender, recipients)
-    msg.content_subtype = 'html'
-    try:
-        msg.send()
-    except:
-        pass
+    email = Email(
+            sender=sender,
+            recipient=recipients,
+            subject=subject,
+            body=body)
+    email.send(fail_silently=True)
+
 
 # return admin auth group as a list
 def get_admin_auth_group(name="Admin"):
@@ -58,43 +59,6 @@ def get_admin_auth_group(name="Admin"):
 
     return auth_group
 
-def user_add_remove_admin_auth_group(user, auth_group=None):
-    """
-    if user is admin and not on admin auth group, add them.
-    if user is not admin but on admin auth group, remove them
-    """
-    if user.is_staff and (not user.is_superuser):   # they are admin
-        if not auth_group:
-            if hasattr(settings, 'ADMIN_AUTH_GROUP_NAME'):
-                auth_group_name = settings.ADMIN_AUTH_GROUP_NAME
-            else:
-                auth_group_name = 'Admin'
-            auth_group = get_admin_auth_group(name=auth_group_name)
-
-
-        if not user.id: # new user
-            user.groups = [auth_group]
-            user.save()
-
-        else:           # existing user
-            group_updated = False
-            user_edit_auth_groups = user.groups.all()
-            if user_edit_auth_groups:
-                if auth_group not in user_edit_auth_groups:
-                    user_edit_auth_groups.append(auth_group)
-                    user.groups = user_edit_auth_groups
-                    group_updated = True
-            else:
-                user.groups = [auth_group]
-                group_updated = True
-
-            if group_updated:
-                user.save()
-
-    else:
-        if user.id:
-            user.groups = []
-            user.save()
 
 def get_groups(user, filter=None):
     """
@@ -146,7 +110,7 @@ def group_choices(user):
 
 
 def update_user(user, **kwargs):
-    for k, v in kwargs.iteritems():
+    for k, v in kwargs.items():
         if hasattr(user, k):
             setattr(user, k, v)
     user.save()
@@ -165,7 +129,7 @@ def make_username_unique(un):
 
     if others and 0 in others:
         # the appended digit will compromise the username length
-        un = '%s%s' % (un, unicode(max(others) + 1))
+        un = '%s%s' % (un, str(max(others) + 1))
 
     return un
 
@@ -191,11 +155,11 @@ def spawn_username(fn=u'', ln=u'', em=u''):
     max_length = django_max_un_length - 3  # to account for appended numbers
 
     # only letters and digits
-    fn = re.sub('[^A-Za-z0-9]', u'', fn)
-    ln = re.sub('[^A-Za-z0-9]', u'', ln)
+    fn = re.sub(r'[^A-Za-z0-9]', u'', fn)
+    ln = re.sub(r'[^A-Za-z0-9]', u'', ln)
 
     # only letters digits underscores dashes @ + .
-    em = re.sub('[^\w@+.-]', u'', em)
+    em = re.sub(r'[^\w@+.-]', u'', em)
 
     if fn and ln:
         un = '%s.%s' % (fn, ln)
@@ -210,20 +174,29 @@ def spawn_username(fn=u'', ln=u'', em=u''):
     if em:
         return make_username_unique(em.split('@')[0][:max_length].lower())
 
-    int_string = ''.join([choice(digits) for x in xrange(10)])
+    int_string = ''.join([choice(digits) for x in range(10)])
     return 'user.%s' % int_string
 
 
-def get_member_reminders(user):
+def get_member_reminders(user, view_self=False):
     active_qs = Q(status_detail__iexact='active')
     expired_qs = Q(status_detail__iexact='expired')
 
     memberships = user.membershipdefault_set.filter(
         status=True) & user.membershipdefault_set.filter(
             active_qs | expired_qs).order_by('expire_dt')
+    count = len(memberships)
 
     reminders = ()
     for membership in memberships:
+        # renew_link depends on membership.app
+        if not membership.app:
+            membership.get_app()
+
+        if count > 1:
+            my_msg = 'Your membership for %s' % membership.membership_type.name
+        else:
+            my_msg = 'Your membership'
 
         renew_link = u''
         if hasattr(membership, 'app') and membership.app:
@@ -238,24 +211,21 @@ def get_member_reminders(user):
         if membership.in_grace_period() or membership.is_expired():
             if membership.can_renew():
                 # expired but can renew
-                message = 'Your membership for %s has expired. Renewal is available until %s.' % (
-                    membership.membership_type.name,
-                    membership.get_renewal_period_end_dt().strftime('%d-%b-%Y %I:%M %p'))
-                reminders += ((message, renew_link, 'Renew your membership now'),)
+                message = format_html(
+                    '{} has expired. <a href="{}">Renew Now</a> to remain an active member!',
+                    my_msg, renew_link)
+                reminders += ((message, renew_link, 'Renew Now'),)
             else:
                 # expired and out of renewal period
-                message = 'Your membership for %s has expired.' % (
-                    membership.membership_type.name)
+                message = format_html('{} has expired.', my_msg)
                 reminders += ((message, renew_link, 'Re-register as a member here'),)
         else:
             # not expired, but in renewal period
             if membership.can_renew():
-                message = 'Your membership for %s will expire on %s. Renewal is available until %s.' % (
-                    membership.membership_type.name,
-                    membership.expire_dt.strftime('%d-%b-%Y'),
-                    membership.get_renewal_period_end_dt().strftime('%d-%b-%Y %I:%M %p')
-                )
-                reminders += ((message, renew_link, 'Renew your membership here'),)
+                message = format_html(
+                    '{} will expire on {}. <a href="{}">Renew Now</a> to remain an active member!',
+                    my_msg, membership.expire_dt.strftime('%d-%b-%Y'), renew_link)
+                reminders += ((message, renew_link, 'Renew Here'),)
 
     return reminders
 
@@ -274,7 +244,7 @@ def clean_username(username):
 
 
 def process_export(export_fields='all_fields', identifier=u'', user_id=0):
-    from tendenci.core.perms.models import TendenciBaseModel
+    from tendenci.apps.perms.models import TendenciBaseModel
 
     if export_fields == 'main_fields':
         user_field_list = [
@@ -297,6 +267,7 @@ def process_export(export_fields='all_fields', identifier=u'', user_id=0):
             'state',
             'zipcode',
             'country',
+            'region',
             'phone',
             'phone2',
             'fax',
@@ -325,7 +296,7 @@ def process_export(export_fields='all_fields', identifier=u'', user_id=0):
             if not field.__class__ == AutoField]
         profile_field_list = [
             name for name in profile_field_list
-            if not name in base_field_list]
+            if name not in base_field_list]
         profile_field_list.remove('guid')
         profile_field_list.remove('user')
         # append base fields at the end
@@ -335,14 +306,14 @@ def process_export(export_fields='all_fields', identifier=u'', user_id=0):
     identifier = identifier or int(ttime.time())
     file_name_temp = 'export/profiles/%s_temp.csv' % identifier
 
-    with default_storage.open(file_name_temp, 'wb') as csvfile:
-        csv_writer = UnicodeWriter(csvfile, encoding='utf-8')
-        csv_writer.writerow(field_list)
+    with default_storage.open(file_name_temp, 'w') as csvfile:
+        csv_writer = csv.DictWriter(csvfile, fieldnames=field_list)
+        csv_writer.writeheader()
 
         profiles = Profile.objects.all()
         for profile in profiles:
             p_user = profile.user
-            items_list = []
+            row_dict = {}
             for field_name in field_list:
                 if field_name in profile_field_list:
                     item = getattr(profile, field_name)
@@ -357,11 +328,8 @@ def process_export(export_fields='all_fields', identifier=u'', user_id=0):
                         item = item.strftime('%Y-%m-%d')
                     elif isinstance(item, time):
                         item = item.strftime('%H:%M:%S')
-                    elif isinstance(item, basestring):
-                        item = item.encode("utf-8")
-                item = smart_str(item).decode('utf-8')
-                items_list.append(item)
-            csv_writer.writerow(items_list)
+                row_dict[field_name] = item
+            csv_writer.writerow(row_dict)
 
     # rename the file name
     file_name = 'export/profiles/%s.csv' % identifier
@@ -385,11 +353,11 @@ def process_export(export_fields='all_fields', identifier=u'', user_id=0):
             'export_fields': export_fields}
 
         subject = render_to_string(
-            'profiles/notices/export_ready_subject.html', parms)
+            template_name='profiles/notices/export_ready_subject.html', context=parms)
         subject = subject.strip('\n').strip('\r')
 
         body = render_to_string(
-            'profiles/notices/export_ready_body.html', parms)
+            template_name='profiles/notices/export_ready_body.html', context=parms)
 
         email = Email(
             recipient=user.email,
@@ -438,7 +406,6 @@ def check_missing_fields(user_data, key, **kwargs):
     return is_valid, missing_field_msg
 
 
-
 def get_user_by_email(email):
     """
     Get user by email address.
@@ -467,7 +434,7 @@ def get_user_by_fn_ln_phone(first_name, last_name, phone):
     """
     Get user by first name, last name and phone.
     """
-    if not any ([first_name, last_name, phone]):
+    if not any([first_name, last_name, phone]):
         return None
 
     profiles = Profile.objects.filter(
@@ -478,7 +445,7 @@ def get_user_by_fn_ln_phone(first_name, last_name, phone):
                     '-user__is_superuser',
                     '-user__is_staff')
     if profiles:
-        return [profile.user  for profile in profiles]
+        return [profile.user for profile in profiles]
     return None
 
 def get_user_by_fn_ln_company(first_name, last_name, company):
@@ -497,7 +464,7 @@ def get_user_by_fn_ln_company(first_name, last_name, company):
                     '-user__is_staff'
                         )
     if profiles:
-        return [profile.user  for profile in profiles]
+        return [profile.user for profile in profiles]
     return None
 
 
@@ -516,12 +483,12 @@ class ImportUsers(object):
         self.uimport = uimport
         self.dry_run = dry_run
         self.summary_d = self.init_summary()
-        self.user_fields = dict([(field.name, field) \
-                            for field in User._meta.fields \
+        self.user_fields = dict([(field.name, field)
+                            for field in User._meta.fields
                             if field.get_internal_type() != 'AutoField'])
-        self.profile_fields = dict([(field.name, field) \
-                            for field in Profile._meta.fields \
-                            if field.get_internal_type() != 'AutoField' and \
+        self.profile_fields = dict([(field.name, field)
+                            for field in Profile._meta.fields
+                            if field.get_internal_type() != 'AutoField' and
                             field.name not in ['user', 'guid']])
         self.private_settings = self.set_default_private_settings()
         self.t4_timezone_map = {'AST': 'Canada/Atlantic',
@@ -532,13 +499,11 @@ class ImportUsers(object):
                              'PST': 'US/Pacific',
                              'GMT': 'UTC'
                              }
-        self.t4_timezone_map_keys = self.t4_timezone_map.keys()
         if self.uimport.group_id:
             [self.uimport.group] = Group.objects.filter(id=self.uimport.group_id)[:1] or [None]
         else:
             self.uimport.group = None
 
-
     def init_summary(self):
         return {
                  'insert': 0,
@@ -613,7 +578,6 @@ class ImportUsers(object):
             elif self.key == 'username':
                 users = User.objects.filter(username__iexact=self.user_data['username'])
 
-
             if users:
                 user_display['action'] = 'update'
                 user_display['user'] = users[0]
@@ -627,7 +591,7 @@ class ImportUsers(object):
                 else:
                     self.summary_d['update'] += 1
 
-                self.field_names = self.user_data.keys()
+                self.field_names = list(self.user_data.keys())
                 # now do the update or insert
                 self.do_import_user(user, self.user_data, user_display)
                 idata.action_taken = user_display['action']
@@ -664,7 +628,7 @@ class ImportUsers(object):
             em=user_data.get('email', u''))
 
         # clean username
-        user.username = re.sub('[^\w+-.@]', u'', user.username)
+        user.username = re.sub(r'[^\w+-.@]', u'', user.username)
 
         # make sure username is unique.
         if action_info['action'] == 'insert':
@@ -679,15 +643,17 @@ class ImportUsers(object):
         if 'password' in self.field_names and self.uimport.override and user.password:
             user.set_password(user.password)
 
-        # is_active; unless forced via import
-        if 'is_active' not in self.field_names:
+        # is_active; interactive or non-interactive
+        if self.uimport.interactive:
             user.is_active = True
+        else:
+            user.is_active = False
 
         user.save()
 
         # process profile
         try:  # get or create
-            profile = user.get_profile()
+            profile = user.profile
         except Profile.DoesNotExist:
             profile = Profile.objects.create(
                 user=user,
@@ -700,7 +666,7 @@ class ImportUsers(object):
         self.assign_import_values_from_dict(profile, action_info['action'])
         profile.user = user
 
-        if profile.status == None or profile.status == '' or \
+        if profile.status is None or profile.status == '' or \
             self.user_data.get('status', '') == '':
             profile.status = True
         if not profile.status_detail:
@@ -715,7 +681,6 @@ class ImportUsers(object):
 
         # add to group
         if self.uimport.group:
-
             if not self.uimport.group.is_member(user):
                 params = {'creator_id': self.request_user.pk,
                       'creator_username': self.request_user.username,
@@ -723,7 +688,6 @@ class ImportUsers(object):
                       'owner_username': self.request_user.username}
                 self.uimport.group.add_user(user, **params)
 
-
     def assign_import_values_from_dict(self, instance, action):
         """
         Assign the import value from a dictionary object
@@ -733,16 +697,15 @@ class ImportUsers(object):
             assign_to_fields = self.user_fields
         elif instance.__class__ == Profile:
             assign_to_fields = self.profile_fields
-        assign_to_fields_names = assign_to_fields.keys()
 
         for field_name in self.field_names:
-            if field_name in assign_to_fields_names:
+            if field_name in assign_to_fields:
                 if any([
                         action == 'insert',
                         self.uimport.override,
-                        not hasattr(instance, field_name) or \
-                        getattr(instance, field_name) == '' or \
-                        getattr(instance, field_name) == None
+                        not hasattr(instance, field_name) or
+                        getattr(instance, field_name) == '' or
+                        getattr(instance, field_name) is None
                         ]):
                     value = self.user_data[field_name]
                     value = self.clean_data(value, assign_to_fields[field_name])
@@ -750,12 +713,12 @@ class ImportUsers(object):
                     setattr(instance, field_name, value)
 
         # if insert, set defaults for the fields not in csv.
-        for field_name in assign_to_fields_names:
+        for field_name in assign_to_fields:
             if field_name not in self.field_names and action == 'insert':
-                if field_name not in self.private_settings.keys():
+                if field_name not in self.private_settings:
                     value = self.get_default_value(assign_to_fields[field_name])
 
-                    if value != None:
+                    if value is not None:
                         setattr(instance, field_name, getattr(instance, field_name) or value)
 
     def get_default_value(self, field):
@@ -765,7 +728,7 @@ class ImportUsers(object):
 
         field_type = field.get_internal_type()
 
-        if field_type == 'BooleanField':
+        if field_type in ['BooleanField', 'NullBooleanField']:
             return False
 
         if field_type == 'DateField':
@@ -784,8 +747,11 @@ class ImportUsers(object):
             return 0
 
         if field_type == 'ForeignKey':
-            [value] = field.related.parent_model.objects.all(
-                                        )[:1] or [None]
+            try:
+                model = field.remote_field.parent_model()
+            except AttributeError:
+                model = field.remote_field.model
+            [value] = model.objects.all()[:1] or [None]
             return value
 
         return ''
@@ -804,7 +770,7 @@ class ImportUsers(object):
                 value = value[:field.max_length]
             if field.name == 'time_zone':
                 if value not in pytz.all_timezones:
-                    if value in self.t4_timezone_map_keys:
+                    if value in self.t4_timezone_map:
                         value = self.t4_timezone_map[value]
             try:
                 value = field.to_python(value)
@@ -814,7 +780,7 @@ class ImportUsers(object):
                 else:
                     value = ''
 
-        elif field_type == 'BooleanField':
+        elif field_type in ['BooleanField', 'NullBooleanField']:
             try:
                 if value in [True, 1, 'TRUE']:
                     value = True
@@ -865,7 +831,6 @@ class ImportUsers(object):
             except:
                 value = 0
         elif field_type == 'ForeignKey':
-            orignal_value = value
             # assume id for foreign key
             try:
                 value = int(value)
@@ -873,13 +838,19 @@ class ImportUsers(object):
                 value = None
 
             if value:
-                [value] = field.related.parent_model.objects.filter(
-                                            pk=value)[:1] or [None]
+                try:
+                    model = field.remote_field.parent_model()
+                except AttributeError:
+                    model = field.remote_field.model
+                [value] = model.objects.filter(pk=value)[:1] or [None]
 
             if not value and not field.null:
                 # if the field doesn't allow null, grab the first one.
-                [value] = field.related.parent_model.objects.all(
-                                        ).order_by('id')[:1] or [None]
+                try:
+                    model = field.remote_field.parent_model()
+                except AttributeError:
+                    model = field.remote_field.model
+                [value] = model.objects.all().order_by('id')[:1] or [None]
 
         return value
 
@@ -899,8 +870,8 @@ def user_import_parse_csv(mimport):
     """
     normalize_newline(mimport.upload_file.name)
     csv_reader = csv.reader(
-        default_storage.open(mimport.upload_file.name, 'rb'))
-    fieldnames = csv_reader.next()
+        default_storage.open(mimport.upload_file.name, 'rU'), )
+    fieldnames = next(csv_reader)
     fieldnames = normalize_field_names(fieldnames)
 
     data_list = []
