@@ -19,7 +19,7 @@ class Redirect(models.Model):
     from_app = models.CharField(_('From App'), max_length=100, db_index=True, blank=True)
     from_url = models.CharField(_('From URL'), max_length=255, db_index=True, blank=True)
     to_url = models.CharField(_('To URL'), max_length=255, db_index=True,
-        help_text=_("You may reference any named regex pattern in From URL with (name). e.g. (?P<slug>[\w\-\/]+) can be mapped to (slug)."))
+        help_text=_(r'You may reference any named regex pattern in From URL with (name). e.g. (?P<slug>[\w\-\/]+) can be mapped to (slug).'))
     http_status = models.SmallIntegerField(_('HTTP Status'),choices=HTTP_STATUS_CHOICES, default=301)
     status = models.SmallIntegerField(choices=STATUS_CHOICES, default=1)
     uses_regex = models.BooleanField(_('Uses Regular Expression'), default=False, help_text=uses_regex_helptext)
@@ -28,8 +28,16 @@ class Redirect(models.Model):
 
     objects = RedirectManager()
 
-    def __unicode__(self):
+    class Meta:
+        app_label = 'redirects'
+
+    def __str__(self):
         if self.from_app:
             return "Redirect from App: %s" % self.from_app
         else:
             return "Redirect from URL: %s" % self.from_url
+
+    def save(self, *args, **kwargs):
+        if 'log' in kwargs:
+            kwargs.pop('log')
+        super(Redirect, self).save(*args, **kwargs)
