@@ -1,16 +1,16 @@
 from haystack import indexes
-from haystack import site
+
 
 from tendenci.apps.redirects.models import Redirect
 
 
-class RedirectIndex(indexes.RealTimeSearchIndex):
+class RedirectIndex(indexes.SearchIndex, indexes.Indexable):
     text = indexes.CharField(document=True, use_template=True)
     from_url = indexes.CharField(model_attr='from_url')
     to_url = indexes.CharField(model_attr='to_url')
     http_status = indexes.IntegerField(model_attr='http_status')
-    status = indexes.BooleanField(model_attr='status')
-    uses_regex = indexes.BooleanField(model_attr='uses_regex')
+    status = indexes.BooleanField(model_attr='status', null=True)
+    uses_regex = indexes.BooleanField(model_attr='uses_regex', null=True)
     create_dt = indexes.DateTimeField(model_attr='create_dt')
     update_dt = indexes.DateTimeField(model_attr='update_dt')
 
@@ -19,10 +19,11 @@ class RedirectIndex(indexes.RealTimeSearchIndex):
 
     order = indexes.DateTimeField()
 
+    def get_model(self):
+        return Redirect
+
     def get_updated_field(self):
         return 'update_dt'
 
     def prepare_order(self, obj):
         return obj.create_dt
-
-site.register(Redirect, RedirectIndex)
