@@ -2,6 +2,7 @@ from django.template import Library
 
 register = Library()
 
+
 @register.inclusion_tag("redirects/options.html", takes_context=True)
 def redirect_options(context, user, redirect):
     context.update({
@@ -10,6 +11,7 @@ def redirect_options(context, user, redirect):
     })
     return context
 
+
 @register.inclusion_tag("redirects/nav.html", takes_context=True)
 def redirect_nav(context, user, redirect=None):
     context.update({
@@ -18,6 +20,16 @@ def redirect_nav(context, user, redirect=None):
     })
     return context
 
+
+@register.inclusion_tag("redirects/top_nav_items.html", takes_context=True)
+def redirect_current_app(context, user, redirect=None):
+    context.update({
+        "app_object" : redirect,
+        "user": user
+    })
+    return context
+
+
 @register.inclusion_tag("redirects/search-form.html", takes_context=True)
 def redirect_search(context):
-    return context
\ No newline at end of file
+    return context
