@@ -4,7 +4,7 @@ from tendenci.apps.registration.models import RegistrationProfile
 
 
 class RegistrationAdmin(admin.ModelAdmin):
-    list_display = ('__unicode__', 'activation_key_expired')
+    list_display = ('id', '__str__', 'activation_key_expired')
     search_fields = ('user__username', 'user__first_name')
 
 
