@@ -8,10 +8,9 @@ from django.utils.translation import ugettext_lazy as _
 from django.template.defaultfilters import filesizeformat
 
 from tendenci.apps.stories.models import Story
-from tendenci.core.perms.forms import TendenciBaseForm
-from tendenci.core.base.fields import SplitDateTimeField
-from tendenci.core.files.utils import get_max_file_upload_size
-from tendenci.core.perms.utils import get_query_filters
+from tendenci.apps.perms.forms import TendenciBaseForm
+from tendenci.apps.files.utils import get_max_file_upload_size
+from tendenci.apps.perms.utils import get_query_filters
 from tendenci.apps.user_groups.models import Group
 
 ALLOWED_LOGO_EXT = (
@@ -26,14 +25,15 @@ END_DT_INITIAL = datetime.now() + timedelta(weeks=2)
 
 class StoryForm(TendenciBaseForm):
     fullstorylink = forms.CharField(label=_("Full Story Link"), required=False, max_length=300)
-    start_dt = SplitDateTimeField(label=_('Start Date/Time'), initial=datetime.now())
-    end_dt = SplitDateTimeField(label=_('End Date/Time'), initial=END_DT_INITIAL)
+    start_dt = forms.SplitDateTimeField(label=_('Start Date/Time'), initial=datetime.now())
+    end_dt = forms.SplitDateTimeField(label=_('End Date/Time'), initial=END_DT_INITIAL)
     expires = forms.BooleanField(
         label=_('Expires'),
         required=False,
         help_text=_('Check if you want this story to expire and be sure to specify the end date.'),
         initial=False,
     )
+    syndicate = forms.BooleanField(label=_('Include in RSS Feed'), required=False, initial=True)
     status_detail = forms.ChoiceField(
         choices=(('active',_('Active')),('inactive',_('Inactive')), ('pending',_('Pending')),))
     photo_upload = forms.FileField(label=_('Photo'), required=False)
@@ -48,6 +48,7 @@ class StoryForm(TendenciBaseForm):
             'content',
             'full_story_link',
             'link_title',
+            'video_embed_url',
             'rotator',
             'tags',
             'photo_upload',
@@ -67,6 +68,7 @@ class StoryForm(TendenciBaseForm):
                       'fields': ['title',
                                  'content',
                                  'photo_upload',
+                                 'video_embed_url',
                                  'full_story_link',
                                  'link_title',
                                  'rotator',
@@ -123,6 +125,20 @@ class StoryForm(TendenciBaseForm):
         except Group.DoesNotExist:
             raise forms.ValidationError(_('Invalid group selected.'))
 
+    def clean_syndicate(self):
+        """
+        clean method for syndicate added due to the update
+        done on the field BooleanField -> NullBooleanField
+        NOTE: BooleanField is converted to NullBooleanField because
+        some Boolean data has value of None than False. This was updated
+        on Django 1.6. BooleanField cannot have a value of None.
+        """
+        data = self.cleaned_data.get('syndicate', False)
+        if data:
+            return True
+        else:
+            return False
+
     def __init__(self, *args, **kwargs):
         super(StoryForm, self).__init__(*args, **kwargs)
         if self.instance.image:
@@ -157,14 +173,15 @@ class StoryForm(TendenciBaseForm):
 
 
 class StoryAdminForm(TendenciBaseForm):
-    start_dt = SplitDateTimeField(label=_('Start Date/Time'), initial=datetime.now())
-    end_dt = SplitDateTimeField(label=_('End Date/Time'), initial=END_DT_INITIAL)
+    start_dt = forms.SplitDateTimeField(label=_('Start Date/Time'), initial=datetime.now())
+    end_dt = forms.SplitDateTimeField(label=_('End Date/Time'), initial=END_DT_INITIAL)
     expires = forms.BooleanField(
         label=_('Expires'),
         required=False,
         help_text=_('Check if you want this story to expire and be sure to specify the end date.'),
         initial=False,
     )
+    syndicate = forms.BooleanField(label=_('Include in RSS Feed'), required=False, initial=True)
     status_detail = forms.ChoiceField(
         choices=(('active',_('Active')),('inactive',_('Inactive')), ('pending',_('Pending')),))
     photo_upload = forms.FileField(label=_('Photo'), required=False)
@@ -178,6 +195,7 @@ class StoryAdminForm(TendenciBaseForm):
             'content',
             'full_story_link',
             'link_title',
+            'video_embed_url',
             'rotator',
             'tags',
             'photo_upload',
@@ -196,6 +214,7 @@ class StoryAdminForm(TendenciBaseForm):
                       'fields': ['title',
                                  'content',
                                  'photo_upload',
+                                 'video_embed_url',
                                  'full_story_link',
                                  'link_title',
                                  'rotator',
@@ -220,6 +239,20 @@ class StoryAdminForm(TendenciBaseForm):
                       'classes': ['admin-only'],
                     })]
 
+    def clean_syndicate(self):
+        """
+        clean method for syndicate added due to the update
+        done on the field BooleanField -> NullBooleanField
+        NOTE: BooleanField is converted to NullBooleanField because
+        some Boolean data has value of None than False. This was updated
+        on Django 1.6. BooleanField cannot have a value of None.
+        """
+        data = self.cleaned_data.get('syndicate', False)
+        if data:
+            return True
+        else:
+            return False
+
     def clean_photo_upload(self):
         photo_upload = self.cleaned_data['photo_upload']
         if photo_upload:
