@@ -1,5 +1,3 @@
-import commands
-from django.conf import settings
 from django.core.management.base import BaseCommand
 from datetime import datetime
 from django.core.management import call_command
@@ -11,7 +9,7 @@ class Command(BaseCommand):
     def handle(self, *args, **kwargs):
         from tendenci.apps.stories.models import Story
         for story in Story.objects.filter(expires=True, status_detail='active'):
-            if story.end_dt < datetime.now():
+            if story.end_dt and story.end_dt < datetime.now():
                 story.status_detail = 'expired'
                 story.save()
         call_command('update_index', *["stories"])
