@@ -1,27 +1,25 @@
-import os.path
+from builtins import str
 
 from django.contrib.auth.decorators import login_required
-from django.shortcuts import render_to_response, get_object_or_404, redirect
-from django.template import RequestContext
+from django.shortcuts import get_object_or_404, redirect
 from django.http import HttpResponseRedirect
-from django.core.urlresolvers import reverse
-from django.conf import settings
+from django.urls import reverse
 from django.contrib import messages
 from django.utils.translation import ugettext_lazy as _
 
-from tendenci.core.base.http import Http403
-from tendenci.core.base.utils import checklist_update
-from tendenci.core.perms.utils import (has_perm, update_perms_and_save,
+from tendenci.apps.base.http import Http403
+from tendenci.apps.base.utils import checklist_update
+from tendenci.apps.perms.utils import (has_perm, update_perms_and_save,
     get_query_filters, has_view_perm)
-from tendenci.core.event_logs.models import EventLog
-from tendenci.core.perms.decorators import is_enabled
-from tendenci.core.site_settings.utils import get_setting
-from tendenci.core.theme.shortcuts import themed_response as render_to_response
-from tendenci.core.exports.utils import run_export_task
+from tendenci.apps.event_logs.models import EventLog
+from tendenci.apps.perms.decorators import is_enabled
+from tendenci.apps.site_settings.utils import get_setting
+from tendenci.apps.theme.shortcuts import themed_response as render_to_resp
+from tendenci.apps.exports.utils import run_export_task
 
 from tendenci.apps.stories.models import Story
 from tendenci.apps.stories.forms import StoryForm
-from tendenci.core.perms.utils import assign_files_perms
+from tendenci.apps.perms.utils import assign_files_perms
 
 
 @is_enabled('stories')
@@ -34,8 +32,8 @@ def details(request, id=None, template_name="stories/view.html"):
 
     EventLog.objects.log(instance=story)
 
-    return render_to_response(template_name, {'story': story},
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'story': story})
 
 
 @is_enabled('stories')
@@ -46,8 +44,8 @@ def print_details(request, id, template_name="stories/print_details.html"):
 
     EventLog.objects.log(instance=story)
 
-    return render_to_response(template_name, {'story': story},
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'story': story})
 
 
 @is_enabled('stories')
@@ -65,14 +63,14 @@ def search(request, template_name="stories/search.html"):
     else:
         filters = get_query_filters(request.user, 'stories.view_story')
         stories = Story.objects.filter(filters).distinct()
-        if request.user.is_authenticated():
+        if request.user.is_authenticated:
             stories = stories.select_related()
         stories = stories.order_by('-create_dt')
 
     EventLog.objects.log()
 
-    return render_to_response(template_name, {'stories':stories},
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'stories':stories})
 
 def search_redirect(request):
     return HttpResponseRedirect(reverse('stories'))
@@ -98,12 +96,12 @@ def add(request, form_class=StoryForm, template_name="stories/add.html"):
                 if 'rotator' in story.tags:
                     checklist_update('add-story')
 
-                messages.add_message(request, messages.SUCCESS, _('Successfully added %(str)s' % {'str': unicode(story)}))
+                messages.add_message(request, messages.SUCCESS, _('Successfully added %(str)s' % {'str': str(story)}))
 
                 return HttpResponseRedirect(reverse('story', args=[story.pk]))
             else:
                 from pprint import pprint
-                pprint(form.errors.items())
+                pprint(list(form.errors.items()))
         else:
             form = form_class(user=request.user)
 
@@ -114,8 +112,8 @@ def add(request, form_class=StoryForm, template_name="stories/add.html"):
     else:
         raise Http403
 
-    return render_to_response(template_name, {'form':form},
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'form':form})
 
 
 @is_enabled('stories')
@@ -137,9 +135,9 @@ def edit(request, id, form_class=StoryForm, template_name="stories/edit.html"):
 
                 story = update_perms_and_save(request, form, story)
 
-                messages.add_message(request, messages.SUCCESS, _('Successfully updated %(str)s' % {'str': unicode(story)}))
+                messages.add_message(request, messages.SUCCESS, _('Successfully updated %(str)s' % {'str': str(story)}))
 
-                redirect_to = request.REQUEST.get('next', '')
+                redirect_to = request.POST.get('next', '')
                 if redirect_to:
                     return HttpResponseRedirect(redirect_to)
                 else:
@@ -150,8 +148,8 @@ def edit(request, id, form_class=StoryForm, template_name="stories/edit.html"):
     else:
         raise Http403
 
-    return render_to_response(template_name, {'story': story, 'form':form },
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'story': story, 'form':form })
 
 
 @is_enabled('stories')
@@ -165,12 +163,12 @@ def delete(request, id, template_name="stories/delete.html"):
                 # Delete story.image to prevent transaction issues.
                 story.image.delete()
             story.delete()
-            messages.add_message(request, messages.SUCCESS, _('Successfully deleted %(str)s' % {'str': unicode(story)}))
+            messages.add_message(request, messages.SUCCESS, _('Successfully deleted %(str)s' % {'str': str(story)}))
 
             return HttpResponseRedirect(reverse('story.search'))
 
-        return render_to_response(template_name, {'story': story},
-            context_instance=RequestContext(request))
+        return render_to_resp(request=request, template_name=template_name,
+            context={'story': story})
     else:
         raise Http403
 
@@ -184,7 +182,6 @@ def export(request, template_name="stories/export.html"):
 
     if request.method == 'POST':
         # initilize initial values
-        file_name = "stories.csv"
         fields = [
             'guid',
             'title',
@@ -202,5 +199,5 @@ def export(request, template_name="stories/export.html"):
         export_id = run_export_task('stories', 'story', fields)
         return redirect('export.status', export_id)
 
-    return render_to_response(template_name, {
-    }, context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name, context={
+    })
