@@ -1,16 +1,20 @@
+from builtins import str
 from collections import OrderedDict
 import time
 from datetime import datetime, date
+import csv
+
 from django.contrib.auth.models import User
 from django.core.files.storage import default_storage
 from django.utils.encoding import smart_str
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.template.loader import render_to_string
 
 from tendenci.apps.user_groups.models import Group
-from tendenci.core.base.utils import UnicodeWriter
-from tendenci.core.site_settings.utils import get_setting
-from tendenci.core.emails.models import Email
+from tendenci.apps.profiles.models import Profile
+#from tendenci.apps.base.utils import UnicodeWriter
+from tendenci.apps.site_settings.utils import get_setting
+from tendenci.apps.emails.models import Email
 
 def member_choices(group, member_label):
     """
@@ -18,13 +22,16 @@ def member_choices(group, member_label):
     member label. This is used for generating choices for a form.
     choices for member label are: email, full name and username.
     """
-    members = User.objects.filter(is_active=1)
+    members = User.objects.all().order_by('username')
     if member_label == 'email':
-        label = lambda x: x.email
+        def label(x):
+            return x.email
     elif member_label == 'full_name':
-        label = lambda x: x.get_full_name()
+        def label(x):
+            return x.get_full_name()
     else:
-        label = lambda x: x.username
+        def label(x):
+            return x.username
     choices = []
     for member in members:
         choices.append((member.pk, label(member)))
@@ -33,10 +40,9 @@ def member_choices(group, member_label):
 
 def get_default_group():
     """
-    get lowest id group to use as default in other apps that FK to Group
+    Get the ID of the default group specified in the global setting
     """
-    return (Group.objects.filter(
-        status=True, status_detail="active").order_by('id')[:1] or [None])[0]
+    return Group.objects.get_initial_group_id()
 
 
 def process_export(
@@ -68,27 +74,33 @@ def process_export(
                    'first_name',
                    'last_name',
                    'email',
+                   'username',
                    'is_active',
                    'is_staff',
                    'is_superuser']
     profile_fields = ['direct_mail',
                       'company',
+                      'department',
+                      'position_title',
                       'address',
                       'address2',
                       'city',
                       'state',
                       'zipcode',
                       'country',
+                      'region',
                       'phone',
+                      'notes',
+                      'referral_source',
                       'create_dt']
     labels = user_fields + profile_fields
 
     field_dict = OrderedDict([(label.lower().replace(" ", "_"), ''
                                ) for label in labels])
 
-    with default_storage.open(file_path_temp, 'wb') as csvfile:
-        csv_writer = UnicodeWriter(csvfile, encoding='utf-8')
-        csv_writer.writerow(field_dict.keys())
+    with default_storage.open(file_path_temp, 'w') as csvfile:        
+        csv_writer = csv.DictWriter(csvfile, fieldnames=list(field_dict.keys()))
+        csv_writer.writeheader()
 
         # process regular group members
         count_members = group.members.filter(
@@ -100,11 +112,14 @@ def process_export(
                 group_member__status=True,
                 group_member__status_detail='active'
                 ).select_related('profile'
-                )[num_rows_processed:(num_rows_processed + rows_per_batch)]
+                ).order_by('group_member__member_id')[num_rows_processed:(num_rows_processed + rows_per_batch)]
             num_rows_processed += rows_per_batch
             row_dict = field_dict.copy()
             for user in users:
-                profile = user.profile
+                if hasattr(user, 'profile'):
+                    profile = user.profile
+                else:
+                    profile = Profile.objects.create_profile(user)
                 for field_name in user_fields:
                     if hasattr(user, field_name):
                         row_dict[field_name] = getattr(user, field_name)
@@ -112,7 +127,7 @@ def process_export(
                     if hasattr(profile, field_name):
                         row_dict[field_name] = getattr(profile, field_name)
                 for k, v in row_dict.items():
-                    if not isinstance(v, basestring):
+                    if not isinstance(v, str):
                         if isinstance(v, datetime):
                             row_dict[k] = v.strftime('%Y-%m-%d %H:%M:%S')
                         elif isinstance(v, date):
@@ -120,7 +135,7 @@ def process_export(
                         else:
                             row_dict[k] = smart_str(v)
 
-                csv_writer.writerow(row_dict.values())
+                csv_writer.writerow(row_dict)
 
     # rename the file name
     file_path = '%sgroup_%d_%s_%s.csv' % (file_dir,
@@ -147,11 +162,11 @@ def process_export(
             'site_display_name': site_display_name}
 
         subject = render_to_string(
-            'user_groups/exports/export_ready_subject.html', parms)
+            template_name='user_groups/exports/export_ready_subject.html', context=parms)
         subject = subject.strip('\n').strip('\r')
 
         body = render_to_string(
-            'user_groups/exports/export_ready_body.html', parms)
+            template_name='user_groups/exports/export_ready_body.html', context=parms)
 
         email = Email(
             recipient=user.email,
