@@ -1,16 +1,15 @@
+
 import subprocess
 from datetime import datetime
 from datetime import date
 import time as ttime
-from djcelery.models import TaskMeta
+# from djcelery.models import TaskMeta
 
-from django.conf import settings
 from django.contrib.auth.decorators import login_required
-from django.shortcuts import get_object_or_404, render_to_response, render, redirect
-from django.template import RequestContext
+from django.shortcuts import get_object_or_404, redirect
 from django.http import HttpResponseRedirect
 from django.contrib.auth.models import User
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.db.models import Count
 from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.sites.models import Site
@@ -19,29 +18,31 @@ from django.http import HttpResponse
 from django.core.files.storage import default_storage
 from django.core.files.base import ContentFile
 from django.http import Http404
-from django.utils.encoding import force_unicode
 from django.utils.translation import ugettext_lazy as _
 
-from tendenci.core.base.http import Http403
-from tendenci.core.site_settings.utils import get_setting
-from tendenci.core.perms.decorators import superuser_required
-from tendenci.core.perms.utils import get_notice_recipients, has_perm, get_query_filters, has_view_perm
-from tendenci.core.imports.forms import ImportForm
-from tendenci.core.imports.models import Import
-from tendenci.core.imports.utils import extract_from_excel, render_excel
+from tendenci.apps.theme.shortcuts import themed_response as render_to_resp
+from tendenci.libs.utils import python_executable
+from tendenci.apps.base.http import Http403
+from tendenci.apps.site_settings.utils import get_setting
+from tendenci.apps.perms.decorators import superuser_required
+from tendenci.apps.perms.utils import get_notice_recipients, has_perm, get_query_filters, has_view_perm
+from tendenci.apps.imports.forms import ImportForm
+from tendenci.apps.imports.models import Import
+from tendenci.apps.imports.utils import render_excel
 from tendenci.apps.entities.models import Entity
-from tendenci.core.event_logs.models import EventLog
-from tendenci.core.event_logs.utils import request_month_range, day_bars
-from tendenci.core.event_logs.views import event_colors
+from tendenci.apps.event_logs.models import EventLog
+from tendenci.apps.event_logs.utils import request_month_range, day_bars
+from tendenci.apps.event_logs.views import event_colors
 from tendenci.apps.user_groups.models import Group, GroupMembership
 from tendenci.apps.user_groups.forms import GroupForm, GroupMembershipForm, GroupSearchForm
-from tendenci.apps.user_groups.forms import GroupForm, GroupMembershipForm, MessageForm
+from tendenci.apps.user_groups.forms import MessageForm
 from tendenci.apps.user_groups.forms import GroupPermissionForm, GroupMembershipBulkForm
+from tendenci.apps.base.decorators import password_required
 #from tendenci.apps.user_groups.importer.forms import UploadForm
 #from tendenci.apps.user_groups.importer.tasks import ImportSubscribersTask
 from tendenci.apps.user_groups.importer.utils import user_groups_import_process
 from tendenci.apps.notifications import models as notification
-from tendenci.core.base.utils import get_deleted_objects
+from tendenci.apps.base.utils import get_deleted_objects
 
 
 def search(request, template_name="user_groups/search.html"):
@@ -57,7 +58,7 @@ def search(request, template_name="user_groups/search.html"):
     filters = get_query_filters(request.user, 'groups.view_group', perms_field=False)
     groups = Group.objects.filter(filters).distinct()
 
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         groups = groups.select_related()
 
     if form.is_valid():
@@ -70,8 +71,8 @@ def search(request, template_name="user_groups/search.html"):
 
     EventLog.objects.log()
 
-    return render_to_response(template_name, {'groups':groups, 'form': form},
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'groups':groups, 'form': form})
 
 def search_redirect(request):
     """
@@ -83,29 +84,38 @@ def search_redirect(request):
 @login_required
 def group_detail(request, group_slug, template_name="user_groups/detail.html"):
     group = get_object_or_404(Group, slug=group_slug)
+    membership_view_perms = get_setting('module', 'memberships', 'memberprotection')
 
     if not has_view_perm(request.user,'user_groups.view_group',group):
         raise Http403
 
+    if group in request.user.profile.get_groups():
+        is_group_member = True
+        gm = GroupMembership.objects.get(group=group, member=request.user)
+    else:
+        is_group_member = False
+        gm = None
+
     EventLog.objects.log(instance=group)
 
-    groupmemberships = GroupMembership.objects.filter(
-        group=group,
-        status=True,
-        status_detail='active').order_by('member__last_name')
+    if request.user.profile.is_superuser or membership_view_perms != 'private':
+        groupmemberships = GroupMembership.objects.filter(
+            group=group,
+            status=True,
+            status_detail='active').order_by('member__last_name')
+    else:
+        groupmemberships = GroupMembership.objects.none()
 
     count_members = len(groupmemberships)
-    return render_to_response(
-        template_name,
-        locals(),
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context=locals())
 
 @superuser_required
 def message(request, group_slug, template_name='user_groups/message.html'):
     """
     Send a message to the group
     """
-    from tendenci.core.emails.models import Email
+    from tendenci.apps.emails.models import Email
 
     group = get_object_or_404(Group, slug=group_slug)
     EventLog.objects.log(instance=group)
@@ -121,14 +131,13 @@ def message(request, group_slug, template_name='user_groups/message.html'):
         request=request,
         num_members=num_members)
 
-
     if request.method == 'POST' and form.is_valid():
 
         email = Email()
         email.sender_display = request.user.get_full_name()
         email.sender = get_setting('site', 'global', 'siteemailnoreplyaddress')
         email.reply_to = email.sender
-        email.content_type = 'text/html'
+        email.content_type = email.CONTENT_TYPE_HTML
         email.subject = form.cleaned_data['subject']
         email.body = form.cleaned_data['body']
         email.save(request.user)
@@ -161,10 +170,9 @@ def message(request, group_slug, template_name='user_groups/message.html'):
         return redirect('group.detail', group_slug=group_slug)
 
     else:
-        print 'form errors', form.errors.items()
+        print('form errors', list(form.errors.items()))
 
-
-    return render(request, template_name, {
+    return render_to_resp(request=request, template_name=template_name, context={
         'group': group,
         'num_members': num_members,
         'form': form})
@@ -225,7 +233,7 @@ def group_add_edit(request, group_slug=None,
         else:
             form = form_class(user=request.user)
 
-    return render_to_response(template_name, {'form':form, 'titie':title, 'group':group}, context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name, context={'form':form, 'titie':title, 'group':group})
 
 
 @login_required
@@ -238,12 +246,12 @@ def group_edit_perms(request, id, form_class=GroupPermissionForm, template_name=
         form = form_class(instance=group_edit)
 
     if form.is_valid():
-        group_edit.permissions = form.cleaned_data['permissions']
+        group_edit.permissions.set(form.cleaned_data['permissions'])
         group_edit.save()
         return HttpResponseRedirect(group_edit.get_absolute_url())
 
-    return render_to_response(template_name, {'group':group_edit, 'form':form},
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'group':group_edit, 'form':form})
 
 def group_delete(request, id, template_name="user_groups/delete.html"):
     group = get_object_or_404(Group, pk=id)
@@ -266,8 +274,8 @@ def group_delete(request, id, template_name="user_groups/delete.html"):
         group.delete()
         return HttpResponseRedirect(reverse('group.search'))
 
-    (deleted_objects, perms_needed, protected) = get_deleted_objects(
-            group, request.user)
+    (deleted_objects, count, perms_needed, protected) = get_deleted_objects(
+            [group], request.user)
     object_name = group.label or group.name
 
     if perms_needed or protected:
@@ -275,16 +283,15 @@ def group_delete(request, id, template_name="user_groups/delete.html"):
     else:
         title = _("Are you sure?")
 
-    return render_to_response(template_name,
-            {'group':group,
+    return render_to_resp(request=request, template_name=template_name,
+        context={'group':group,
              "title": title,
              "object_name": object_name,
              "deleted_objects": deleted_objects,
              "perms_lacking": perms_needed,
              "protected": protected,
              "opts": group._meta,
-             },
-        context_instance=RequestContext(request))
+             })
 
 def group_membership_self_add(request, slug, user_id):
     group = get_object_or_404(Group, slug=slug)
@@ -309,6 +316,9 @@ def group_membership_self_add(request, slug, user_id):
 
         EventLog.objects.log(instance=group_membership)
 
+        if group_membership.is_newsletter_subscribed:
+            group_membership.subscribe_to_newsletter()
+
         messages.add_message(request, messages.SUCCESS, _('Successfully added yourself to group %(grp)s' % {'grp':group}))
     else:
         messages.add_message(request, messages.INFO, _('You are already in the group %(grp)s' % {'grp': group}))
@@ -388,7 +398,7 @@ def groupmembership_bulk_add(request, group_slug,
         member_label = request.GET.get('member_label', 'username')
         form = form_class(group, member_label=member_label)
 
-    return render_to_response(template_name, locals(), context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name, context=locals())
 
 def groupmembership_add_edit(request, group_slug, user_id=None,
                              form_class=GroupMembershipForm,
@@ -427,7 +437,7 @@ def groupmembership_add_edit(request, group_slug, user_id=None,
     else:
         form = form_class(group, user_id, instance=group_membership)
 
-    return render_to_response(template_name, locals(), context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name, context=locals())
 
 
 def groupmembership_delete(request, group_slug, user_id, template_name="user_groups/member_delete.html"):
@@ -450,7 +460,7 @@ def groupmembership_delete(request, group_slug, user_id, template_name="user_gro
         )
         return HttpResponseRedirect(group.get_absolute_url())
 
-    return render_to_response(template_name, locals(), context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name, context=locals())
 
 
 def _events_chart(from_date, to_date, event_ids):
@@ -492,13 +502,12 @@ def users_added_report(request, kind):
             .annotate(count=Count('pk'))\
             .order_by('-count')
 
-    return render_to_response('reports/users_added.html',
-                              {'data': data, 'chart_data': chart_data,
+    return render_to_resp(request=request, template_name='reports/users_added.html',
+                              context={'data': data, 'chart_data': chart_data,
                                'report_title': title,
                                'entities': Entity.objects.all().order_by('entity_name'),
                                'site': Site.objects.get_current(),
-                               'date_range': (from_date, to_date)},
-                              context_instance=RequestContext(request))
+                               'date_range': (from_date, to_date)})
 
 
 @login_required
@@ -519,7 +528,7 @@ def group_members_export(request, group_slug, export_target='all'):
                                             identifier)
     default_storage.save(temp_export_path, ContentFile(''))
     # start the process
-    subprocess.Popen(["python", "manage.py",
+    subprocess.Popen([python_executable(), "manage.py",
                   "group_members_export",
                   '--group_id=%d' % group.id,
                   '--export_target=%s' % export_target,
@@ -580,7 +589,7 @@ def group_members_export_status(request, group_slug,
                'export_target': export_target,
                'download_ready': download_ready,
                'email_recipient': email_recipient}
-    return render_to_response(template, context, RequestContext(request))
+    return render_to_resp(request=request, template_name=template, context=context)
 
 
 @login_required
@@ -598,8 +607,8 @@ def group_members_export_download(request, group_slug, export_target, identifier
     if not default_storage.exists(export_path):
         raise Http404
 
-    response = HttpResponse(mimetype='text/csv')
-    response['Content-Disposition'] = 'attachment; filename=membership_export_%s' % file_name
+    response = HttpResponse(content_type='text/csv')
+    response['Content-Disposition'] = 'attachment; filename="membership_export_%s"' % file_name
     response.content = default_storage.open(export_path).read()
     return response
 
@@ -615,7 +624,7 @@ def group_member_export(request, group_slug):
         raise Http403
 
     import xlwt
-    from ordereddict import OrderedDict
+    from collections import OrderedDict
     from django.db import connection
 
     # create the excel book and sheet
@@ -642,12 +651,12 @@ def group_member_export(request, group_slug):
         ('is_active', 'au.is_active'),
         ('date', 'gm.create_dt'),
     ])
-    group_lookups = ','.join(group_mappings.values())
+    group_lookups = ','.join(list(group_mappings.values()))
 
     # Use custom sql to fetch the rows because we need to
     # populate the user profiles information and you
     # cannot do that with django's ORM without using
-    # get_profile() for each user query
+    # profile for each user query
     # pulling 13,000 group members can be done in one
     # query using Django's ORM but then you need
     # 13,000 individual queries :(
@@ -662,7 +671,7 @@ def group_member_export(request, group_slug):
 
     # Append the heading to the list of values that will
     # go into the excel sheet
-    values_list.insert(0, group_mappings.keys())
+    values_list.insert(0, list(group_mappings.keys()))
 
     # excel date styles
     default_style = xlwt.Style.default_style
@@ -682,8 +691,8 @@ def group_member_export(request, group_slug):
                     style = default_style
                 sheet.write(row, col, val, style=style)
 
-    response = HttpResponse(mimetype='application/vnd.ms-excel')
-    response['Content-Disposition'] = 'attachment; filename=group_%s_member_export.xls' % group.pk
+    response = HttpResponse(content_type='application/vnd.ms-excel')
+    response['Content-Disposition'] = 'attachment; filename="group_%s_member_export.xls"' % group.pk
     book.save(response)
     return response
 
@@ -698,8 +707,6 @@ def group_subscriber_export(request, group_slug):
         raise Http403
 
     import xlwt
-    from ordereddict import OrderedDict
-    from django.db import connection
     from tendenci.apps.forms_builder.forms.models import FieldEntry
 
     # create the excel book and sheet
@@ -723,7 +730,7 @@ def group_subscriber_export(request, group_slug):
             row = row_index[entry.entry.pk]
         else:
             # assign the row if it is not yet available
-            row = len(row_index.keys()) + 1
+            row = len(row_index) + 1
             row_index[entry.entry.pk] = row
 
         if entry.field.label in col_index:
@@ -732,7 +739,7 @@ def group_subscriber_export(request, group_slug):
         else:
             # assign the col if it is not yet available
             # and label the new column
-            col = len(col_index.keys())
+            col = len(col_index)
             col_index[entry.field.label] = col
             sheet.write(0, col, entry.field.label, style=default_style)
 
@@ -746,8 +753,8 @@ def group_subscriber_export(request, group_slug):
 
         sheet.write(row, col, val, style=style)
 
-    response = HttpResponse(mimetype='application/vnd.ms-excel')
-    response['Content-Disposition'] = 'attachment; filename=group_%s_subscriber_export.xls' % group.pk
+    response = HttpResponse(content_type='application/vnd.ms-excel')
+    response['Content-Disposition'] = 'attachment; filename="group_%s_subscriber_export.xls"' % group.pk
     book.save(response)
     return response
 
@@ -802,12 +809,12 @@ def group_all_export(request, group_slug):
         ('is_active', 'au.is_active'),
         ('date', 'gm.create_dt'),
     ])
-    group_lookups = ','.join(group_mappings.values())
+    group_lookups = ','.join(list(group_mappings.values()))
 
     # Use custom sql to fetch the rows because we need to
     # populate the user profiles information and you
     # cannot do that with django's ORM without using
-    # get_profile() for each user query
+    # profile for each user query
     # pulling 13,000 group members can be done in one
     # query using Django's ORM but then you need
     # 13,000 individual queries :(
@@ -821,9 +828,9 @@ def group_all_export(request, group_slug):
     values_list = list(cursor.fetchall())
 
     # index the group key mappings and insert them into the sheet.
-    for key in group_mappings.keys():
-        if not key in col_index:
-            col = len(col_index.keys())
+    for key in group_mappings:
+        if key not in col_index:
+            col = len(col_index)
             col_index[key] = col
             sheet.write(0, col, key, style=default_style)
 
@@ -832,7 +839,7 @@ def group_all_export(request, group_slug):
         for row, row_data in enumerate(values_list):
             for col, val in enumerate(row_data):
 
-                if not row in row_index:
+                if row not in row_index:
                     # assign the row if it is not yet available
                     row_index[row] = row + 1
 
@@ -860,7 +867,7 @@ def group_all_export(request, group_slug):
             row = row_index["subscriber %s" % str(entry.entry.pk)]
         else:
             # assign the row if it is not yet available
-            row = len(row_index.keys()) + 1
+            row = len(row_index) + 1
             row_index["subscriber %s" % str(entry.entry.pk)] = row
 
         if field in col_index:
@@ -869,7 +876,7 @@ def group_all_export(request, group_slug):
         else:
             # assign the col if it is not yet available
             # and label the new column
-            col = len(col_index.keys())
+            col = len(col_index)
             col_index[field] = col
             sheet.write(0, col, field, style=default_style)
 
@@ -883,8 +890,8 @@ def group_all_export(request, group_slug):
 
         sheet.write(row, col, val, style=style)
 
-    response = HttpResponse(mimetype='application/vnd.ms-excel')
-    response['Content-Disposition'] = 'attachment; filename=group_%s_all_export.xls' % group.pk
+    response = HttpResponse(content_type='application/vnd.ms-excel')
+    response['Content-Disposition'] = 'attachment; filename="group_%s_all_export.xls"' % group.pk
     book.save(response)
     return response
 
@@ -917,20 +924,20 @@ def group_subscriber_import(request, group_slug, template="user_groups/import_su
     #             # evaluate the result and render the results page
     #             result = ImportSubscribersTask()
     #             subs = result.run(group, csv.file.path)
-    #             return render_to_response('user_groups/import_subscribers_result.html', {
+    #             return render_to_resp(request=request, template_name='user_groups/import_subscribers_result.html', context={
     #                 'group':group,
     #                 'subs':subs,
-    #             }, context_instance=RequestContext(request))
+    #             })
     #         else:
     #             result = ImportSubscribersTask.delay(group, csv.file.path)
     #             return redirect('subscribers_import_status', group.slug, result.task_id)
     # else:
     #     form = form_class()
 
-    # return render_to_response(template, {
+    # return render_to_resp(request=request, template_name=template, context={
     #     'group':group,
     #     'form':form,
-    # }, context_instance=RequestContext(request))
+    # })
 
 @login_required
 def subscribers_import_status(request, group_slug, task_id, template_name='user_groups/import_status.html'):
@@ -950,24 +957,25 @@ def subscribers_import_status(request, group_slug, task_id, template_name='user_
 
     if task and task.status == "SUCCESS":
         subs = task.result
-        return render_to_response('user_groups/import_subscribers_result.html', {
+        return render_to_resp(request=request, template_name='user_groups/import_subscribers_result.html', context={
             'group':group,
             'subs':subs,
-        }, context_instance=RequestContext(request))
+        })
     else:
-        return render_to_response(template_name, {
+        return render_to_resp(request=request, template_name=template_name, context={
             'group':group,
             'task':task,
-        }, context_instance=RequestContext(request))
+        })
 
 @login_required
 def groupmembership_bulk_add_redirect(request, template_name='user_groups/bulk_add_redirect.html'):
     EventLog.objects.log()
 
-    return render_to_response(template_name, {}, context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name)
 
 
 @login_required
+@password_required
 def import_add(request, form_class=ImportForm,
                 template_name="user_groups/imports/user_groups_add.html"):
     """Event Import Step 1: Validates and saves import file"""
@@ -991,8 +999,8 @@ def import_add(request, form_class=ImportForm,
                 reverse('group.import_preview', args=[import_i.id]))
     else:
         form = form_class()
-    return render_to_response(template_name, {'form': form},
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context={'form': form})
 
 @login_required
 def import_preview(request, import_id,
@@ -1005,11 +1013,11 @@ def import_preview(request, import_id,
     user_groups_list, invalid_list = user_groups_import_process(import_i,
                                                         preview=True)
 
-    return render_to_response(template_name, {
+    return render_to_resp(request=request, template_name=template_name, context={
         'total': import_i.total_created + import_i.total_invalid,
         'user_groups_list': user_groups_list,
         'import_i': import_i,
-    }, context_instance=RequestContext(request))
+    })
 
 @login_required
 def import_process(request, import_id,
@@ -1021,12 +1029,12 @@ def import_process(request, import_id,
 
     import_i = get_object_or_404(Import, id=import_id)
 
-    subprocess.Popen(['python', 'manage.py', 'import_groups', str(import_id)])
+    subprocess.Popen([python_executable(), 'manage.py', 'import_groups', str(import_id)])
 
-    return render_to_response(template_name, {
+    return render_to_resp(request=request, template_name=template_name, context={
         'total': import_i.total_created + import_i.total_invalid,
         "import_i": import_i,
-    }, context_instance=RequestContext(request))
+    })
 
 @login_required
 def import_download_template(request, file_ext='.csv'):
@@ -1044,3 +1052,58 @@ def import_download_template(request, file_ext='.csv'):
     data_row_list = []
 
     return render_excel(filename, import_field_list, data_row_list, file_ext)
+
+# Newsletter stuff here:
+@login_required
+def subscribe_to_newsletter_interactive(request, group_slug):
+    group = get_object_or_404(Group, slug=group_slug,
+                              allow_self_add=True,
+                              status_detail='active')
+
+    [groupmembership] = GroupMembership.objects.filter(
+                        group=group,
+                        member=request.user,
+                        status=True,
+                        status_detail='active')[:1] or [None]
+    if not groupmembership:
+        groupmembership = GroupMembership.add_to_group(group=group,
+                                                       member=request.user)
+
+    if groupmembership.subscribe_to_newsletter():
+        messages.success(request, _('Successfully subscribed to Newsletters.'))
+
+    return redirect(reverse('group.detail', kwargs={'group_slug': group_slug}))
+
+
+@login_required
+def unsubscribe_to_newsletter_interactive(request, group_slug):
+    group = get_object_or_404(Group, slug=group_slug)
+
+    groupmembership = get_object_or_404(GroupMembership,
+                        group=group,
+                        member=request.user,
+                        status=True,
+                        status_detail='active')
+
+    if groupmembership.unsubscribe_to_newsletter():
+        messages.success(request, _('Successfully unsubscribed to Newsletters.'))
+
+    return redirect(reverse('group.detail', kwargs={'group_slug': group_slug}))
+
+
+def subscribe_to_newsletter_noninteractive(request, group_slug):
+    pass
+
+
+def unsubscribe_to_newsletter_noninteractive(request, group_slug, newsletter_key):
+    group = get_object_or_404(Group, slug=group_slug)
+
+    groupmembership = get_object_or_404(GroupMembership,
+                        group=group,
+                        status=True,
+                        status_detail='active',
+                        newsletter_key=newsletter_key)
+    if not groupmembership.unsubscribe_to_newsletter():
+        raise Http404
+
+    return render_to_resp(request=request, template_name='user_groups/newsletter_unsubscribe.html')
