@@ -4,7 +4,7 @@ from django.contrib.auth.models import User
 
 class XMLExport (models.Model):
     # who made the import
-    author = models.ForeignKey(User)
+    author = models.ForeignKey(User, on_delete=models.CASCADE)
     # when
     xml_export_date = models.DateTimeField(auto_now_add=True)
     # file
