@@ -1,4 +1,4 @@
-from utils import gen_xml
+from .utils import gen_xml
 
 def test_run():
     f = open('test_result.txt', 'w+')
