@@ -1,11 +1,10 @@
 from django.db import models
 from django.contrib.auth.models import User
-from tendenci.core.files.models import File
-from datetime import datetime
+from tendenci.apps.files.models import File
 
 class BlogImport(models.Model):
     # who made the import
-    author = models.ForeignKey(User)
+    author = models.ForeignKey(User, on_delete=models.CASCADE)
     # when
     blog_import_date = models.DateTimeField(auto_now_add=True)
     # file
@@ -13,4 +12,4 @@ class BlogImport(models.Model):
 
 class AssociatedFile(models.Model):
     post_id = models.IntegerField()
-    file = models.ForeignKey(File)
+    file = models.ForeignKey(File, on_delete=models.CASCADE)
