@@ -2,29 +2,31 @@ from django.db import models
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.contenttypes import generic
+from django.contrib.contenttypes.fields import GenericRelation
 from django.utils.safestring import mark_safe
-from timezones.fields import TimeZoneField
 
-from tendenci.core.event_logs.models import EventLog
-from tendenci.core.perms.object_perms import ObjectPermission
+from timezone_field import TimeZoneField
+
+from tendenci.apps.base.utils import get_timezone_choices
+from tendenci.apps.event_logs.models import EventLog
+from tendenci.apps.perms.object_perms import ObjectPermission
 
 # Abstract base class for authority fields
 class TendenciBaseModel(models.Model):
     # authority fields
-    allow_anonymous_view = models.BooleanField(_("Public can view"), default=True)
-    allow_user_view = models.BooleanField(_("Signed in user can view"))
-    allow_member_view = models.BooleanField()
-    allow_user_edit = models.BooleanField(_("Signed in user can change"))
-    allow_member_edit = models.BooleanField()
+    allow_anonymous_view = models.NullBooleanField(_("Public can view"), default=False)
+    allow_user_view = models.NullBooleanField(_("Signed in user can view"))
+    allow_member_view = models.NullBooleanField()
+    allow_user_edit = models.NullBooleanField(_("Signed in user can change"))
+    allow_member_edit = models.NullBooleanField()
 
     create_dt = models.DateTimeField(auto_now_add=True)
     update_dt = models.DateTimeField(auto_now=True)
-    creator = models.ForeignKey(User, related_name="%(app_label)s_%(class)s_creator", editable=False)
+    creator = models.ForeignKey(User, related_name="%(app_label)s_%(class)s_creator", editable=False, on_delete=models.CASCADE)
     creator_username = models.CharField(max_length=50)
-    owner = models.ForeignKey(User, related_name="%(app_label)s_%(class)s_owner")
+    owner = models.ForeignKey(User, related_name="%(app_label)s_%(class)s_owner" , on_delete=models.CASCADE)
     owner_username = models.CharField(max_length=50)
-    status = models.BooleanField(_("Active"), default=True)
+    status = models.NullBooleanField("Active", default=True)
     status_detail = models.CharField(max_length=50, default='active')
 
     class Meta:
@@ -36,12 +38,12 @@ class TendenciBaseModel(models.Model):
 
     @property
     def opt_module_name(self):
-        return self._meta.module_name
+        return self._meta.model_name
 
     @property
     def obj_perms(self):
-        from tendenci.core.perms.fields import has_groups_perms
-        t = '<span class="perm-%s">%s</span>'
+        from tendenci.apps.perms.fields import has_groups_perms
+        t = '<span class="t-profile-perm t-perm-%s">%s</span>'
 
         if self.allow_anonymous_view:
             value = t % ('public','Public')
@@ -58,7 +60,7 @@ class TendenciBaseModel(models.Model):
 
     @property
     def obj_status(obj):
-        t = '<span class="status-%s">%s</span>'
+        t = '<span class="t-profile-status t-status-%s">%s</span>'
 
         if obj.status:
             if obj.status_detail == 'paid - pending approval':
@@ -91,17 +93,23 @@ class TendenciBaseModel(models.Model):
         super(TendenciBaseModel, self).delete(*args, **kwargs)
 
 
+class UnsavedOneToOne(models.OneToOneField):
+    # A ForeignKey which can point to an unsaved object
+    allow_unsaved_instance_assignment = True
+
 class Person(TendenciBaseModel):
-    user = models.OneToOneField(User, related_name="profile", verbose_name=_('user'))
+    user = UnsavedOneToOne(User, related_name="profile", verbose_name=_('user'), on_delete=models.CASCADE)
     phone = models.CharField(_('phone'), max_length=50, blank=True)
     address = models.CharField(_('address'), max_length=150, blank=True)
     address2 = models.CharField(_('address2'), max_length=100, default='', blank=True)
     member_number = models.CharField(_('member number'), max_length=50, blank=True)
     city = models.CharField(_('city'), max_length=50, blank=True)
+    region = models.CharField(_('region'), max_length=50, blank=True, default='')
     state = models.CharField(_('state'), max_length=50, blank=True)
     zipcode = models.CharField(_('zipcode'), max_length=50, blank=True)
     county = models.CharField(_('county'), max_length=50, blank=True)
-    country = models.CharField(_('country'), max_length=50, blank=True)
+    country = models.CharField(_('country'), max_length=255, blank=True)
+    is_billing_address = models.BooleanField(_('Is billing address'), default=True)
 
     # fields to be used for the alternate address
     address_2 = models.CharField(_('address'), max_length=150, blank=True)
@@ -111,14 +119,15 @@ class Person(TendenciBaseModel):
     state_2 = models.CharField(_('state'), max_length=50, blank=True)
     zipcode_2 = models.CharField(_('zipcode'), max_length=50, blank=True)
     county_2 = models.CharField(_('county'), max_length=50, blank=True)
-    country_2 = models.CharField(_('country'), max_length=50, blank=True)
+    country_2 = models.CharField(_('country'), max_length=255, blank=True)
+    is_billing_address_2 = models.BooleanField(_('Is billing address'), default=False)
 
     url = models.CharField(_('url'), max_length=100, blank=True)
 
-    time_zone = TimeZoneField(_('timezone'))
+    time_zone = TimeZoneField(verbose_name=_('Time Zone'), default='US/Central', choices=get_timezone_choices(), max_length=100)
     language = models.CharField(_('language'), max_length=10, choices=settings.LANGUAGES, default=settings.LANGUAGE_CODE)
 
-    perms = generic.GenericRelation(ObjectPermission,
+    perms = GenericRelation(ObjectPermission,
         object_id_field="object_id", content_type_field="content_type")
 
     class Meta:
