@@ -1,37 +1,45 @@
 # -*- coding: utf-8 -*-
-from datetime import date, timedelta
-
 from django import forms
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext as _
-from django.utils.encoding import force_unicode
+from django.utils.encoding import force_text
+from django.forms.widgets import DateInput
 
 
 class RangeWidget(forms.MultiWidget):
+    """
+    Render 2 inputs with vDatepicker class in order to select a date range.
+    """
+    template_name = 'model_report/widgets/range_widget.html'
+
     def __init__(self, widget, *args, **kwargs):
         widgets = (widget, widget)
         kwargs['attrs'] = {'class': 'vDatepicker'}
         super(RangeWidget, self).__init__(widgets=widgets, *args, **kwargs)
 
     def decompress(self, value):
-        raise value
         return value
 
-    def format_output(self, rendered_widgets):
-        widget_context = {'min': rendered_widgets[0], 'max': rendered_widgets[1]}
-        return render_to_string('model_report/widgets/range_widget.html', widget_context)
+    def get_context(self, name, value, attrs):
+        context = super(RangeWidget, self).get_context(name, value, attrs)
+        widgets = context['widget']['subwidgets']
+        context['min'] = DateInput(widgets[0]['attrs']).render(widgets[0]['name'], widgets[0]['value'] or '')
+        context['max'] = DateInput(widgets[1]['attrs']).render(widgets[1]['name'], widgets[1]['value'] or '')
+        return context
 
 
 class RangeField(forms.MultiValueField):
+    """
+    Field to filter date values by range.
+    """
     default_error_messages = {
         'invalid_start': _(u'Enter a valid start value.'),
         'invalid_end': _(u'Enter a valid end value.'),
     }
 
     def __init__(self, field_class, widget=forms.TextInput, *args, **kwargs):
-        if not 'initial' in kwargs:
-            now = date.today()
-            kwargs['initial'] = [str(now - timedelta(days=30)), str(now)]
+        if 'initial' not in kwargs:
+            kwargs['initial'] = ['', '']
 
         fields = (field_class(), field_class())
 
@@ -40,7 +48,8 @@ class RangeField(forms.MultiValueField):
                 widget=RangeWidget(widget),
                 *args, **kwargs
                 )
-        self.label = force_unicode(field_class().label)
+        self.label = force_text(field_class().label)
+
 
     def compress(self, data_list):
         if data_list:
